package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````(!L!`#0```#,T@```@(`!30`(``)
M`"@`'``;``$``'!8R@``6,H!`%C*`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!0````0````#````5`$``%0!`0!4`0$`$P``
M`!,````$`````0````$````````````!`````0!DR@``9,H```4```````$`
M`0```-S.``#<S@(`W,X"`%@"``"@$@``!@```````0`"````Z,X``.C.`@#H
MS@(`&`$``!@!```&````!`````0```!H`0``:`$!`&@!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DW,X`
M`-S.`@#<S@(`)`$``"0!```$`````0```"]L:6(O;&0M;&EN=7@N<V\N,P``
M!````!`````!````1TY5```````"````!@```"`````$````%`````,```!'
M3E4`#K1>CV-T0!057M!72[ZMD932["%A````!0```"`````*````H!(`"`)$
M$2```D``5@!P&,((`#`(`!41```0`@`H`````````$@"(`H`"@`$A`.H0`A%
M8&D`A`D^0CR7``$`""18@`0)8`R3>`E"6@!``$```0!""0!`@(S`A```$)`0
M@PD`"`$0@(%`0,()@"Q`F`)!`"``(`0)@)0!I`Z7=D`%``````````8````'
M````"0`````````````````````````*````#`````X````0````$0```!(`
M```4````%P`````````9```````````````:````'0```!X`````````(@``
M`",````D`````````"4````F````*@`````````L```````````````M````
M+@```"\````P`````````#0````U`````````#D``````````````#H````]
M````/@`````````_````0````$(```!$````1P````````!*````2P```$P`
M``!-`````````$X```````````````````````````````````!/````4```
M``````!2`````````%0```!6````6`````````````````````````!9````
M70````````!?`````````&$`````````8P```&0``````````````&8```!G
M````:0```&H```!M````7Y:3'*-:[Y!6VY,<PXZ'_PTZEPO2402$@72"#7KP
M2FM]08[%=E0\E,T_#*_W(\X@B0=PTR!TL`+59-1\9J_,9BY./?;;]P!>!J2'
M_P&O-.BQ2)WGSDJN_\[>1RWAIP(*XT?&`<8.X#T^?I9\[#^0`FUSA<7%B060
M89CO$@$C^:2=NY,<0D75[%#N$>.&^9R!?>T1#[J5DQQ;FCL/04V=?*?=HVM9
M[Y=Y.?*+'`P4XIX$,J6%H@+V&=O-XY[[H6Q@ZM/O#L@Y0!\R8MOMN8WQ#NG[
MP\)*(GW_"HH05^W>DQRM2^/`V7%8'"O0X2(:G]:]+0ZQ<U@[0!_#Y3\LF"+4
M:+KCDGPA_^0.BIC=PFYZ:?J+V357DZT$8C?C\,%#\N_(WX4@3U>DFY;%N9Q`
M4!M]7S&X@@V^VE<;LP&+;[S02WUW;^-P:@E#UI\BQZ@A8F0'?JF<FV+0^H+L
M+/:+:W^:?(;PEGS1GRS\[@M1^?/;TQV0=8(-0V9+$`5LLLT\K3D-%^I:\:/@
M^TGB5\085Y):4OW2[P]NQ=\??)`0Z2W?_D@NQ9NVWJO*G\G5LG$`````````
M````````````$0``````````````(````"T``````````````"`````\````
M```````````@````4```````````````(````)D#`````````````!(```!<
M`@`````````````2````\P(`````````````$@```-<"`````````````!(`
M``"4!```)-$"```````@`!<`S0$`````````````$@```-`"````````````
M`!(```"]`0``!!8!```````2````(`4```R$`0`\````$@`-`/T#```TT0(`
M`````!``&`"*`@`````````````2````M0(`````````````$@```-0$```P
MT0(`!````!$`%P`V`P`````````````2````/`4``,Q_`0#$`P``$@`-`'D$
M```\<0$`)`$``!(`#0"@`P`````````````2````FP(`````````````$@``
M`$<#`````````````!(````,!```?.$"```````0`!@`#P$`````````````
M$@```%<$`````````````!(```"%!```R'4!``0*```2``T`K@0``#1N`0#L
M````$@`-`&P$```4<0$`*````!(`#0#"`@`````````````2````A0(`````
M````````$@```)8!`````````````!(````C`P`````````````2````LP,`
M`#C1`@`$````(0`8`$0"`````````````!(```!+`@`````````````2````
MY0(`````````````$@```.H#```TT0(``````!``%P```P`````````````2
M````G@```#@8`0``````$@```,H"`````````````!(```!K`P``````````
M```2````/@(`````````````$@```&0"`````````````!(```"T`P``.-$"
M``0````A`!@`%P0``'SA`@``````$``8`$`#``!0T0(`!````!$`&``D!```
MV(0!``0````2``T`H0$`````````````$@```&\!`````````````!(```#$
M!```;(0!`&P````2``T```4``+!T`0`8`0``$@`-`"X$```\B@$``````!(`
M#@"D`@`````````````2````F`0``"`;`0``````$@`-`.T$``!H%0$`````
M`!(`"P"^```````````````2````%0,`````````````$@````(!``!,T0(`
M`0```!$`&`#>`@`````````````2````GP0``$B*`0`$````$0`/`/$#```T
MT0(``````!``&`!R`P`````````````2````B@,`````````````$@```&H`
M`````````````!(````<`0`````````````2````ZP0``*1M`0`X````$@`-
M`#@!`````````````!(````?!```?.$"```````0`!@`\P0``"1O`0#P`0``
M$@`-`-,``````````````!(```!S`@`````````````2````AP``````````
M````$@```"H"`````````````!(```"O`0`````````````2````X0``````
M````````$@```/,``````````````!(````M`0``2-$"``0````1`!@`L@,`
M`#C1`@`$````$0`8`&$!`````````````!(```#L`@`````````````2````
M"P0``'SA`@``````$``8`!(%```4=`$`@````!(`#0"O```````````````2
M````+@,`````````````$@```)($```DT0(``````!``%P!\`P``````````
M```2````R@,``$#1`@`$````$0`8`$4$``"4=`$`'````!(`#0#K`0``````
M```````2````V`$`````````````$@```*T#``#(&`$`6`(``!(`#0`]`0``
M```````````2````5P,`````````````$@```$X#`````````````!(```#V
M`0``5-$"`!,````1`!@`#@,`````````````$@```/H"`````````````!(`
M``"2`@`````````````2````Y`$`````````````$@```)(#````````````
M`!(```#>!```8'(!`+0!```2``T`7@,`````````````$@```$(!````````
M`````!(```"\`@`````````````2````8`0``)"#`0!\````$@`-`'@`````
M`````````!(```!_`0`````````````2````-`0``"!O`0`$````$@`-`(@!
M`````````````!(```!.`0``P!<!```````2`````&QI8G!E<FPN<V\N-2XR
M,`!?251-7V1E<F5G:7-T97)434-L;VYE5&%B;&4`7U]G;6]N7W-T87)T7U\`
M7TIV7U)E9VES=&5R0VQA<W-E<P!?251-7W)E9VES=&5R5$U#;&]N951A8FQE
M`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]S879E7V1E<W1R
M=6-T;W)?>`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?
M8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA
M9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W4U9P=@!0
M97)L7VYE=UA37V9L86=S`%!,7W1H<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?
M<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?
M9F5T8VAP=@!P97)L7W)U;@!097)L7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R
M;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O;W1?1'EN84QO861E<@!P97)L
M7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R
M>5]W<F%P`&QI8F1L+G-O+C(`;&EB;2YS;RXV`&QI8G!T:')E860N<V\N,`!P
M=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&]P96XV-`!?7V5R<FYO7VQO8V%T
M:6]N`&QS965K-C0`<F5A9`!L:6)C+G-O+C8`7U]R96=I<W1E<E]A=&9O<FL`
M97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L;W-E9&ER`%]?<W1A8VM?8VAK7V9A
M:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`86)O<G0`;65M8VAR`&=E='!I9`!S
M=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H
M:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?7VQX<W1A=#8T`&]P96YD:7(`7U]X
M<W1A=#8T`'-T9&5R<@!G971U:60`<F5A9&QI;FL`97AE8W9P`%]?;65M8W!Y
M7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A
M8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L9"UL
M:6YU>"YS;RXS`%]?<W1A8VM?8VAK7V=U87)D`&QI8F-R>7!T+G-O+C$`7V5D
M871A`%]?8G-S7W-T87)T`%]?8G-S7W-T87)T7U\`7U]B<W-?96YD7U\`7U]E
M;F1?7P!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E
M=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E
M;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`7U]D871A7W-T87)T`%])
M3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U
M7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD
M<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R
M;F%L<U]005)?0TQ%05)35$%#2P!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)
M0D-?,BXT```````````````"``,``@`"``$````"`````0`!``(``@`!``(`
M`0`!``(``@`"``$````"``$``0`!``(``@````(``@`#``,``@`!``(````"
M``(``P`#``(``0`"``$```````$``0`!``(``0`!`````@````(``0`!``(`
M`@```````0````$``0````(````#`````````````@````(``0`!`````@`!
M``(`!``!```````!``(``@`"`````@`"``(``@`"``$``@````(``0``````
M`0```````0`!`+P#```0````(````!1I:0T```0`4@4````````!``$`&@(`
M`!`````@````%&EI#0```P!2!0````````$``0!I`@``$``````````4:6D-
M```"`%(%````````(-$"`!4"```XT0(`%$\``$#1`@`46```2-$"`!1.``!,
MT0(`%#L``%#1`@`4+P``5-$"`!1@```,T`(`%@<``!#0`@`6!0``%-`"`!8:
M```8T`(`%BP``!S0`@`6%P``(-`"`!9````DT`(`%ET``"C0`@`61P``+-`"
M`!9A```PT`(`%EX``#30`@`6#```.-`"`!9B```\T`(`%E0``$#0`@`61```
M1-`"`!8Z``!(T`(`%C8``$S0`@`62```4-`"`!80``!4T`(`%AX``%C0`@`6
M,0``7-`"`!90``!@T`(`%E\``&30`@`69P``:-`"`!9,``!LT`(`%EH``'#0
M`@`6!@``=-`"`!9N``!XT`(`%EL``'S0`@`650``@-`"`!8C``"$T`(`%F0`
M`(C0`@`6%0``C-`"`!8R``"0T`(`%@(``)30`@`6"```F-`"`!8?``"<T`(`
M%B4``*#0`@`6:P``I-`"`!8J``"HT`(`%AD``*S0`@`6)```L-`"`!97``"T
MT`(`%CD``+C0`@`68P``O-`"`!8@``#`T`(`%FD``,30`@`640``R-`"`!9O
M``#,T`(`%D$``-#0`@`6:```U-`"`!8*``#8T`(`%B<``-S0`@`60@``X-`"
M`!8+``#DT`(`%F4``.C0`@`6/```[-`"`!9+``#PT`(`%B@``/30`@`6/P``
M^-`"`!9-``#\T`(`%FP```#1`@`620``!-$"`!82```(T0(`%@\```S1`@`6
M*0``$-$"`!8K```4T0(`%B$``!C1`@`6%@``'-$"`!9*```(0"WI>@$`ZPA`
MO>@>_R_A!.`MY03@G^4.X(_@"/"^Y7BZ`0``QH_B&\J,XGCZO.4`QH_B&\J,
MXG#ZO.4`QH_B&\J,XFCZO.4`QH_B&\J,XF#ZO.4`QH_B&\J,XECZO.4`QH_B
M&\J,XE#ZO.4`QH_B&\J,XDCZO.4`QH_B&\J,XD#ZO.4`QH_B&\J,XCCZO.4`
MQH_B&\J,XC#ZO.4`QH_B&\J,XBCZO.4`QH_B&\J,XB#ZO.4`QH_B&\J,XACZ
MO.4`QH_B&\J,XA#ZO.4`QH_B&\J,X@CZO.4`QH_B&\J,X@#ZO.4`QH_B&\J,
MXOCYO.4`QH_B&\J,XO#YO.4`QH_B&\J,XNCYO.4`QH_B&\J,XN#YO.4`QH_B
M&\J,XMCYO.4`QH_B&\J,XM#YO.4`QH_B&\J,XLCYO.4`QH_B&\J,XL#YO.4`
MQH_B&\J,XKCYO.4`QH_B&\J,XK#YO.4`QH_B&\J,XJCYO.4`QH_B&\J,XJ#Y
MO.4`QH_B&\J,XICYO.4`QH_B&\J,XI#YO.4`QH_B&\J,XHCYO.4`QH_B&\J,
MXH#YO.4`QH_B&\J,XGCYO.4`QH_B&\J,XG#YO.4`QH_B&\J,XFCYO.4`QH_B
M&\J,XF#YO.4`QH_B&\J,XECYO.4`QH_B&\J,XE#YO.4`QH_B&\J,XDCYO.4`
MQH_B&\J,XD#YO.4`QH_B&\J,XCCYO.4`QH_B&\J,XC#YO.4`QH_B&\J,XBCY
MO.4`QH_B&\J,XB#YO.4`QH_B&\J,XACYO.4`QH_B&\J,XA#YO.4`QH_B&\J,
MX@CYO.4`QH_B&\J,X@#YO.4`QH_B&\J,XOCXO.4`QH_B&\J,XO#XO.4`QH_B
M&\J,XNCXO.4`QH_B&\J,XN#XO.4`QH_B&\J,XMCXO.4`QH_B&\J,XM#XO.4`
MQH_B&\J,XLCXO.4`QH_B&\J,XL#XO.4`QH_B&\J,XKCXO.4`QH_B&\J,XK#X
MO.4`QH_B&\J,XJCXO.4`QH_B&\J,XJ#XO.4`QH_B&\J,XICXO.4`QH_B&\J,
MXI#XO.4`QH_B&\J,XHCXO.4`QH_B&\J,XH#XO.4`QH_B&\J,XGCXO.4`QH_B
M&\J,XG#XO.4`QH_B&\J,XFCXO.4`QH_B&\J,XF#XO.4`QH_B&\J,XECXO.7P
M0"WI#'*?Y2303>(`,)?E%`"-Y1`0C>4,((WE%`"-XA`0C>(,((WB'#"-Y9/_
M_^OD$9_EY`&?Y0$@H.'/&@#KW#&?Y0!0T^4``%7CU$&?%0D``!IB___KS"&?
MY0``4./H#P+E:0``"KA!G^4X___K``"4Y=[__^LM5L#E``"4Y=O__^L`(*#A
MWC/0Y0(P@^/>,\+E``"4Y=7__^L40)WEWC/0Y05`A.(!,(/CWC/`Y00`H.&=
M&P#K`""@XP`PH./6&@#K9"&?Y60QG^4B'`#K``!0XT(``!H$`:#A2?__ZP0P
MH.,`4*#A$$"=Y401G^44()WE`."4Y3S!G^4$`)'E)&&?Y301G^4!`%+C!,"%
MY0P0A>4`X(7E!!"$P@@`A>7P7P;E]#\&Y0)!A,`,P(7"`P``V@3@D>0$`%'A
M!."LY?O__QH`P*#C#>&"X@#`C>4%,*#AZ`\6Y0,@@N+@$)_E#L&%YVS__^L`
M0%#BN#"?Y1(```KH#Q;E"O__ZQ@0C>+``)_E!!,`ZP``4..84)_E#@``"N@/
M%N7P_O_K6/__ZQP@G>4`,)?E`P!2X00`H.$5```:)-"-XO!`O>@>_R_AZ`\3
MY7+__^L`0*#AZ/__ZNP/%>4``%#C!```"CD:`.OK___J8`"?Y6`0G^4R___K
M&!"-XE@`G^7G$@#K``!0X^P/!>7B__\*\___ZMG^_^L!`*#C$___ZT#1`@#`
M%P$`.!@!`$S1`@!(T0(`8/$"````@/___\]!+-$"`-R-`0#@C0$`W&T!`(R+
M`0"XC`$`5-$"`"B+`0``L*#C`."@XP00G>0-(*#A!"`MY00`+>40P)_E!,`M
MY0P`G^4,,)_E[/[_ZT[__^O8A`$`R!@!`&R$`0`4,)_E%""?Y0,PC^`"()/G
M``!2XQ[_+P'G_O_JE+0!`"`!```<,)_E'`"?Y0,P8.`&`%/C'O\OD1`PG^4`
M`%/C'O\O`1/_+^$WT0(`--$"```````D$)_E)`"?Y0$08.!!$:#AH1^!X,$0
ML.$>_R\!$#"?Y0``4^,>_R\!$_\OX331`@`TT0(``````!!`+>D<0)_E`##4
MY0``4^,"```:W___ZP$PH.,`,,3E$$"]Z![_+^%GT0(`"$`MZ2@`G^4`,)#E
M``!3XP$``!H(0+WHW___ZA0PG^4``%/C^O__"@_@H.$3_R_A]___ZN3.`@``
M````\$\MZ;O?3>)@<(WB!^"@X<P_G^4`,)/E>&"`XD"@C>5$L(WE,`"-Y>0R
MC>4H8(WE.'"-Y3C`@.)``ISH"32@X0@PC>4&-*#A`#"-Y0`PH.,FK*#A":2*
MX02@C>4IO*#A`P"=Z``0H.,,L(WE%#"-Y0!PH.,(,(WB#`"3Z``PH.,F1*#A
M_P@`X@9LH.$&`(#A*52@X2``C>4D$(WE"4R$X?\H`N()G*#A`!"@XQ!0C>4)
M8(+A''"-Y0-PH.$0,(WB#`"3Z``PH.,@D(WB``.9Z/\,!.(`@(CA`9")X1BP
MC>7_+`+B"`"@X0D0H.$&((+A!S"#X0"0H.,8<(WBP`"7Z`!PH./_8`;B!B""
MX2A@G>7_@`KB",",X@@`@.$)$('A!S"#X08`7.$#`([H""".Y0PPCN40X([B
MOO__&CAPG>7(P(WBH%"-XG!`C>+@X(WBLF^-X@P`O.@#`+7H`@`@X`,0(>`,
M`+3H`@`@X`,0(>`,`+?H`Q`AX``PH.,"`"#@H*^@X0`@D."!H(KA"B""X08`
M7.$,`*[H[?__&C#@G>4@,([B#`"3Z`(`H.$#$*#A`("@XP"0H.-@,(WB#`"3
MZ``,GNA0`(WE5!"-Y0(`D.`#$*'@"""@X0DPH.$`#(WHJHV@X8I"H.$`H*#C
M$`"-Y100C>6+@HCAZ)V?Y1#`C>(`&)SH"""-Y0PPC>4)L)O@"#".X@P`D^@*
MP*S@`Q"@X0N0H.$,H*#A`@"@X1"0C>44H(WE`9"@X0A`A.$`@*#A&#".X@P`
MD^@@((WE)#"-Y2#`C>(`&)SH`1#,X0``R^$!L*#A"1"@X0"@H.$(`*#A`%"@
MXQ`PCN(,`)/H&""-Y1PPC>4#D`G@`3^@X0PPC>4`/Z#A"#"-Y0*`".`@8:#A
M$#"-X@P`D^@!;X;A#&"-Y00@DN`*@(CA`#"CX@N0B>$(0)+@2`"-Y4P0C>4(
M$(WB`P"1Z`5PH.$)4*/@``.=Z`8`@.$`8*#A"1"@X0@`H.$$L*#A!<"@X08`
M`.`'$`'@.`"-Y3P0C>4H8(WE+'"-Y1APC>+``)?H.%"-XC``E>@)D,?A"Z"@
MX0E0A>$`D*#C$+"-Y13`C>4`L*#C:#"-X@P`D^@@$(WB`P"1Z`(`D.`#$*'@
M"(#&X3``C>4T$(WE"$"$X3A`C>4\4(WE=(R?Y3!0C>(P`)7H!("8X`60J>"J
M+:#A,`"=Z(LB@N&*PJ#A#""-Y0C`C>4D`:#A!&^@X04/@.$(4(WB,`"5Z`)`
MA.$$(*#A.%"-XC``E>@(0)3@"5"EX`60H.$`4*#C!("@X040H.$"4)C@!@"`
MX0!@J>(P4(WE-&"-Y1!@C>)@`);H`%`%X`%@!N!P,(WB#`"3Z%A0C>5<8(WE
M&&"-XF``EN@"4)7@`V"FX"A`C>(8`)3H"C##X0M`Q.$#(*#A!#"@X4!0C>5$
M8(WE6'"-XL``E^@#<(?A`#"@XS!0C>(P`)7H`%"@XP)@AN%88(WE7'"-Y8`K
MG^5`<(WBP`"7Z`8@DN`X`(WE/!"-Y0<PH^`J`:#A0""-Y40PC>4+#X#A"C^@
MX10`C>40,(WE$#"-X@P`D^BD/:#A0*"-X@`&FNB%,H/A6'"-XL``E^@(,(WE
MI3V@X0E@EN`,,(WE`"""X0IPI^`"`*#A"#"-X@P`D^B$@J#A!Y"@X0!PH.,(
M((+A!H"@X0"@H.$'L*#A`F"8X`!PJ>(`D*#C,#"-X@P`D^AX$(WB`P"1Z,R*
MG^4PH(WE-+"-Y0LP`^``P*#C`+"@XP"`F.`!D*G@"1"@X0J0H.$(L(WE#,"-
MY2BPC>(`#)OH"*":X`&PJ^`08(WE%'"-Y3APC>+``)?H**"-Y2RPC>40$(WB
M`P"1Z``0H.,%<,?A`\"'X21QH.$(<(WE"*"=Y06OBN$(H(WE):&@X0R@C>4$
M8,;A!(^@X0A0C>(P`)7H"2`"X`A`A.$HD(WB``.9Z`*PAN$+@)C@"*"@X:`M
MH.&`8J#A@2*"X08@@N$`8*#C#)"IX`1PH.$"0)K@`%"IX@A`C>4,4(WE@#"-
MX@P`D^@`@*#CX%F?Y0)0E>`#8*;@!2"@X08PH.$08(WB8`"6Z`=0!>`(8`;@
M$'"-Y12`C>5`4(WE1&"-Y3APC>+``)?H`F"6X`-PI^`(,(WB#`"3Z``PH.,P
ML(WB``R;Z"A@C>4L<(WE0'"-XL``E^@`H,KA`;#+X0I@AN$+<(?A($&@X3A@
MC>4\<(WE`(^@X0%/A.$(0(3A*!"-X@,`D>@XD(WB``.9Z**MH.&#HHKA@F*@
MX0@`D.`*8(;A"1"AX`:`D.`0<(WBP`"7Z`)@QN$#<,?A.&"-Y3QPC>4`8*#C
M`)"AX@#`H..($(WB`P"1Z/A8G^4$L*#A`%"5X`%@IN`&$*#A*("-Y2R0C>4(
MH(WB``::Z`R@"N`(L(WE#,"-Y0IPH.$PL(WB``R;Z`6@FN`!L*O@,*"-Y32P
MC>4HL(WB``R;Z`"PH.,*`*#A"Q"@X3BPC>(`#)OH!)`)X`F@BN$'L(OA"\"@
MX0JPH.&@K:#A@:**X8!BH.$*8(;A(D&@X0"@H.,XL(WE/,"-Y0*/H.$#3X3A
M"$"$X3`PC>(,`)/H.)"-X@`#F>@(()+@`("@XPDPH^`&D)+@"E"@X0"@H^(P
MD(WE-*"-Y2!XG^60,(WB#`"3Z`)PE^`#@*C@!R"@X0@PH.$0<(WBP`"7Z"B0
MC>(``YGH`F"6X`-PI^`$@`C@,#"-X@P`D^@%D`G@`#"@XSB`C>4\D(WE"+"-
MX@`,F^@08(WE%'"-Y3APC>+``)?H`*#*X0&PR^$H0(WE+%"-Y0I@AN$+<(?A
M($&@X3A@C>4\<(WE`(^@X0%/A.$(0(3A$!"-X@,`D>@XD(WB``.9Z`@`D.``
M@*#CHJV@X8.BBN&"8J#A"F"&X0D0H>`&L)#@*'"-XL``E^@"8,;A`W#'X3A@
MC>4\<(WE`,"AXCQWG^68$(WB`P"1Z`20H.$`H*#C`'"7X`&`J.`'`*#A"!"@
MX3"`C>*``9CH$+"-Y13`C>4PD(WE-*"-Y0J`".`(L(WB``R;Z`1P!^``H)K@
M`;"KX`=@H.$(H(WE#+"-Y1#`C>(`&)SH`,"@XPL`H.$XL(WB``R;Z`:@BN$(
ML(OA#!"@X0O`H.$*L*#A(D&@X3BPC>4\P(WE`H^@X0-/A.$(0(3A"#"-X@P`
MD^@XD(WB``.9Z*"MH.&!HHKA@&*@X0@@DN`*8(;A"3"CX`:@DN``8*#C`,"@
MXP"PH^)@5I_EH#"-X@P`D^@"4)7@`V"FX`4@H.$&,*#A!("@X0R0H.$08(WB
M8`"6Z`10!>`,8`;@.%"-Y3Q@C>4H<(WBP`"7Z`)@EN`#<*?@"*"-Y0RPC>40
M@(WE%)"-Y3"PC>(`#)OH*&"-Y2QPC>4(,(WB#`"3Z``PH.,X<(WBP`"7Z`"@
MRN$!L,OA"F"&X0MPA^$@0:#A.&"-Y3QPC>4`CZ#A`4^$X0A`A.$H$(WB`P"1
MZ#B0C>(``YGHHJV@X8.BBN&"8J#A"`"0X`I@AN$)$*'@!I"0X!!PC>+``)?H
M`F#&X0-PQ^$X8(WE/'"-Y0!@H.,`H*'B;%6?Y:@0C>(#`)'H!+"@X0#`H.,`
M4)7@`6"FX`80H.$HD(WE+*"-Y0B`C>*``9CH"+"-Y0S`C>4PL(WB``R;Z`6@
MFN`!L*O@,*"-Y32PC>4HL(WB``R;Z`"PH.,$<`?@!V"@X0H`H.$+$*#A.+"-
MX@`,F^@,@`C@!J"*X0BPB^$+P*#A"K"@X2)!H.$XL(WE/,"-Y0*/H.$#3X3A
M"$"$X3`PC>(,`)/H.)"-X@`#F>B@K:#A@:**X8!BH.$(()+@"F"&X0DPH^`&
M@)+@`)"CX@"@H.,P@(WE-)"-Y0"`H..P,(WB#`"3Z(1TG^4*4*#A`G"7X`BP
MC>(`#)OH`X"HX`<@H.$`H,KA`;#+X0@PH.$+P*#A"K"@X1!PC>+``)?H`F"6
MX`-PI^`08(WE%'"-Y0M@H.$HH(WB``::Z`20">`%H`K@.)"-Y3R@C>4XL(WB
M``R;Z`I@AN$+<(SA!\"@X0:PH.$P,(WB#`"3Z``PH.,H0(WE+%"-Y2!!H.$X
ML(WE/,"-Y0"/H.$!3X3A"$"$X1`0C>(#`)'H.)"-X@`#F>BBK:#A@Z**X8)B
MH.$(`)#@"F"&X0D0H>`&L)#@`,"AXA"PC>44P(WEN!"-X@,`D>@H<(WBP`"7
MZ`)@QN$#<,?A.&"-Y3QPC>4`8*#C@%.?Y020H.$`H*#C`%"5X`%@IN`&$*#A
M,("-XH`!F.@PD(WE-*"-Y0J`".`(L(WB``R;Z`1P!^`%H)K@!V"@X0&PJ^`(
MH(WE#+"-Y1#`C>(`&)SH`,"@XPL`H.$XL(WB``R;Z")!H.$&H(KA"+"+X3B@
MC>4\L(WE`H^@X0-/A.$(0(3A"#"-X@P`D^@XD(WB``.9Z`P0H.$(()+@H*V@
MX0"`H..,HHKA`,"@XX!BH.$*8(;A"3"CX`:@DN``L*/BP'*?Y<`PC>(,`)/H
M"*"-Y0RPC>4PL(WB``R;Z`)PE^``H,KA`;#+X0.`J.`'(*#A.*"-Y3RPC>4,
M4*#A"#"@X1#`C>(`&)SH!+`+X`N@H.$H<(WBP`"7Z`)@EN`#<*?@*&"-Y2QP
MC>4X<(WBP`"7Z`7`#.`*8(;A#'"'X0:PH.$'P*#A"#"-X@P`D^@`,*#C$$"-
MY110C>4@0:#A.+"-Y3S`C>4`CZ#A`4^$X0A`A.$H$(WB`P"1Z#B0C>(``YGH
MHJV@X8.BBN&"8J#A"`"0X`I@AN$)$*'@!H"0X!!PC>+``)?H`F#&X0-PQ^$X
M8(WE/'"-Y0!@H.,`D*'BQ%&?Y<@0C>(#`)'H!+"@X0#`H.,`4)7@`6"FX`80
MH.$H@(WE+)"-Y0B`C>*``9CH"+"-Y0S`C>4PL(WB``R;Z`6@FN`!L*O@,*"-
MY32PC>4HL(WB``R;Z`"PH.,$<`?@!V"@X0H`H.$+$*#A.+"-X@`,F^@,@`C@
M!J"*X0BPB^$+P*#A"K"@X2)!H.$XL(WE/,"-Y0*/H.$#3X3A"$"$X3`PC>(,
M`)/H.)"-X@`#F>B@K:#A@:**X8!BH.$(()+@"F"&X0DPH^`&@)+@`)"CX@"@
MH.,P@(WE-)"-Y0"`H./0,(WB#`"3Z-QPG^4*4*#A`G"7X`BPC>(`#)OH`X"H
MX`<@H.$`H,KA`;#+X0@PH.$+P*#A"K"@X1!PC>+``)?H`F"6X`-PI^`08(WE
M%'"-Y0M@H.$HH(WB``::Z`20">`%H`K@.)"-Y3R@C>4XL(WB``R;Z`I@AN$+
M<(SA!\"@X0:PH.$P,(WB#`"3Z``PH.,H0(WE+%"-Y2!!H.$XL(WE/,"-Y0"/
MH.$!3X3A"$"$X1`0C>(#`)'H.)"-X@`#F>BBK:#A@Z**X8)BH.$(`)#@"F"&
MX0D0H>`&L)#@*'"-XL``E^@"``#J0-$"`)EY@EJAZ]EN`F#&X0-PQ^$X8(WE
M/'"-Y0!@H.,`P*'B*%`?Y=@0C>(#`)'H!)"@X0"@H.,`4)7@`6"FX`80H.$P
M@(WB@`&8Z!"PC>44P(WE,)"-Y32@C>4*@`C@"+"-X@`,F^@$<`?@!:":X`=@
MH.$!L*O@"*"-Y0RPC>40P(WB`!B<Z`#`H.,+`*#A.+"-X@`,F^@B0:#A!J"*
MX0BPB^$XH(WE/+"-Y0*/H.$#3X3A"$"$X0@PC>(,`)/H.)"-X@`#F>@,$*#A
M"""2X*"MH.$`@*#CC***X0#`H..`8J#A"F"&X0DPH^`&H)+@`+"CXOAP'^7@
M,(WB#`"3Z`B@C>4,L(WE,+"-X@`,F^@"<)?@`*#*X0&PR^$#@*C@!R"@X3B@
MC>4\L(WE#%"@X0@PH.$0P(WB`!B<Z`2P"^`+H*#A*'"-XL``E^@"8);@`W"G
MX"A@C>4L<(WE.'"-XL``E^@%P`S@"F"&X0QPA^$&L*#A!\"@X0@PC>(,`)/H
M`#"@XQ!`C>444(WE($&@X3BPC>4\P(WE`(^@X0%/A.$(0(3A*!"-X@,`D>@X
MD(WB``.9Z`@`D.``@*#CHJV@X8.BBN&"8J#A"F"&X0D0H>`&L)#@$'"-XL``
ME^@"8,;A`W#'X0#`H>)`8(WE1'"-Y>@0C>(#`)'H_'$?Y0"@H.,`<)?@`8"H
MX`<`H.$($*#A"("-XH`!F.@HL(WE+,"-Y0I0H.$*@`C@,+"-X@`,F^@`H)K@
M`;"KX`1P!^`(H(WE#+"-Y0=@H.$HP(WB`!B<Z`#`H.,+`*#A0+"-X@`,F^@,
M$*#A.$"-Y3Q0C>4&H(KA"+"+X2)!H.$PH(WE-+"-Y0*/H.$#3X3A"$"$X0@P
MC>(,`)/H,)"-X@`#F>@(()+@`("@XZ"MH.&,HHKA@&*@X0I@AN$),*/@!K"2
MX#APC>+``)?H`&#&X0%PQ^$P8(WE-'"-Y020H.'<<A_E\%"-XC``E>@`H*#C
M`,"CX@1PE^`%@*C@"%"@X2@PC>(,`)/H*)"-Y2R@C>4)(`+@$)"-X@`#F>@'
M@)C@!9"IX`HP`^`P4(WB,`"5Z""AH.$(L(WE#,"-Y0&OBN$AL:#A`&^@X0H0
MB^$"0(3A`U"%X08`BN$`8*#A,$"-Y310C>4!<*#A`%"@XQ"`C>44D(WE")"-
MX@`#F>@`D*#C$!"-X@,`D>@PP(WB`!B<Z$!@C>5$<(WE!7"@X0L`D.``L*#C
MJ"V@X8A"H.&)(H+A!"""X0P0H>`"0)#@`%"AXC!`C>4T4(WE*$"-XA@`E.@(
M,,/A"4#$X010H.$#0*#A"#"-X@P`D^CX$(WB`P"1Z.RC'^588(WE7'"-Y08@
M`N`',`/@`&"@XP!PH.,`H)K@`;"KX`H`H.$+$*#A"&"-Y0QPC>4X<(WBP`"7
MZ`*PH.$#P*#A`&"6X#`PC>(,`)/H`#"@XP%PI^```*#C`!"@XZ*MH.$(H(WE
M@Z*@X1``C>44$(WE%*"-Y0B@G>6#HHKA"*"-Y12@G>6BK8KA!`"+X12@C>6C
MK:#A`&"6X`40C.$,H(WE@J*@X0%PI^`0H(WE.&"-Y3QPC>4(L(WB``R;Z!!P
MC>+``)?H*$&@X0E/A.$*8(;A*5&@X3B@C>(`!IKH"`^@X0:0F>``L(3A!,"%
MX0"@JN(+0*#A"K"@X0F@H.%`<(WBP`"7Z`Q0H.$$8";@#'`GX`&<C>(``YGH
M!@"@X0<0H.%`H(WE1+"-Y11E'^4`L*#C"&"6X`:`H.$`<*#C.$"-Y3Q0C>4P
M8(WB8`"6Z*K-H.$`4"7@`6`FX(O"C.$P4(WE-&"-Y0C`C>4H4(WB,`"5Z*O-
MH.$,P(WE,,"=Y0EPI^`(0)3@!U"EX`P`E.`B0:#A`!"EX@-/A.$C4:#A`C^@
MX11`C>40,(WE$#"-X@P`D^@$((+A!3"#X2@`C>4L$(WE`A"@X0,@H.$`4*#C
M")"-X@`#F>@H0(WB&`"4Z(IBH.$&@(CA"#"3X`!`I.(#@*#A!)"@X3A`C>(8
M`)3H*!"-Y2P@C>4!,"/@0!"-X@,`D>A"?XWBP`"7Z`1&'^4#`"#@`""@XP`P
MH.,&0)3@!U"EX`1@H.$%<*#A`$"@XP!0H.,P@(WE-)"-Y0"0H.,0((WE%#"-
MY5@@C>(&`)+H!A"1X`A`C>4,4(WE!R"BX`!`D>`J`:#A"P^`X2L1H.$`L('A
M"S"@X:C-H.$(P(WEB<*@X13`C>4(P)WEB<*,X0C`C>44P)WEJ,V,X13`C>6I
MS:#A#,"-Y8C"H.$0P(WE`%"BXD!`C>5$4(WE"'"-XL``E^@04(WB,`"5Z`HO
MH.$"H(#A0!"-X@,`D>@&0(3A!`"0X`-`H.$`P*#C"B"@X2BPC>(`#)OH`!"A
MX@2P*^``8*#A`7"@X0M0H.$1'HWB`P"1Z`RW'^4`L)O@`<"LX`P0H.$`P*#C
M"P"@X0:PH.$0((WE%#"-Y0PPH.$"H"K@0&"-Y41PC>4&(*#A,'"-XL``E^@*
M8";@!7`GX#!@C>4T<(WE.,"=Y0Q`D."+PJ#A","-Y3#`G>6KK:#A`%"AXH.B
MBN$,8)3@#*"-Y0!PI>(P8(WE-'"-Y2A!H.$(<(WBP`"7Z`E/A.$I4:#A"`^@
MX0"0A.$*8(;A!*"%X0FPH.$*P*#A,*"-X@`&FN@&D)G@$'"-XL``E^@PL(WE
M-,"-Y0QP)^``P*#C1E^-XC``E>@+8";@[+<?Y0"@JN($L)O@"T"@X07`K.`,
M4*#A.)"-Y3R@C>4)`*#A":"@X4"0C>(``YGH*,"=Y0:`*.`'D"G@0("-Y420
MC>4`L*#C#&"4X$#`G>4`<*7B#&"6X"+!H.$#SXSA#%"@X0C`C>4CP:#A#,"-
MY0#`H..JK:#ABZ**X8""H.$*@(CA`'"GX@A@EN`"3Z#A`'"GX@@PC>(,`)/H
M!Z"@X3"`C>*``9CH!"""X04P@^$&D*#A`G`GX`.`*.`27HWB,`"5Z`L0H.$'
M8*#AN+@?Y0APH.$$L)O@!<"LX`Q0H.$H((WE+#"-Y4"0C>5$H(WE"2"@X3B0
MC>(``YGH$,"=Y0:`*.`'D"G@.("-Y3R0C>4,8)O@.,"=Y0!PI>(,8);@(,&@
MX0'/C.$,4*#A`#"@XPC`C>4AP:#A#,"-Y0!/H.$($(WB`P"1Z`0`@.$%$('A
M`<"@X0"PH.&BK:#A@Z**X8*"H.$*@(CA`'"GX@A@EN``<*?B!I"@X0>@H.$0
ML(WE%,"-Y0#`H.-*7XWB,`"5Z'RY'^4XD(WE/*"-Y0"@H.,$L)O@!<"LX`Q0
MH.$H<(WBP`"7Z`!@)N`)`*#A0)"-X@`#F>@!<"?@,,"=Y0:`*.`'D"G@0("-
MY420C>4*$*#A#&";X$#`G>4`<*7B#&"6X"+!H.$#SXSA#%"@X0"0H..@K:#A
M@:**X8""H.$(P(WE"H"(X2/!H.$,P(WE`'"GX@A@EN`"3Z#A`'"GX@@PC>(,
M`)/H!["@X1"`C>*``9CH!"""X04P@^$"<"?@`X`HX!->C>(P`)7H!J"@X0=@
MH.$(<*#A4(H?Y02`F.`(0*#A!9"IX`E0H.$XD(WB``.9Z"C`G>4&@"C@!Y`I
MX#B`C>4\D(WE#&"4X#C`G>4`<*7B#&"6X"#!H.$!SXSA#%"@X3`@C>4T,(WE
M"B"@X0`PH.,(P(WE(<&@X0S`C>4`3Z#A"!"-X@,`D>@$`(#A!1"!X4"@C>5$
ML(WE`<"@X0"PH.&JK:#A@Z**X8*"H.$*@(CA`'"GX@A@EN``<*?B!I"@X0>@
MH.$HL(WE+,"-Y0#`H.-.7XWB,`"5Z!2['^4XD(WE/*"-Y0"@H.,$L)O@!<"L
MX`Q0H.$P<(WBP`"7Z`!@)N`)`*#A0)"-X@`#F>@!<"?@$,"=Y0:`*.`'D"G@
M"A"@X4"`C>5$D(WE#&";X$#`G>4`<*7B#&"6X"+!H.$#SXSA#%"@X0"0H..@
MK:#A@:**X8""H.$*@(CA","-Y2/!H.$,P(WE`'"GX@A@EN`"3Z#A`'"GX@@P
MC>(,`)/H!["@X2B`C>*``9CH!"""X04P@^$&H*#A`G`GX`.`*.`%78WB,`"5
MZ`=@H.$(<*#AZ(L?Y02`F.`(0*#A!9"IX`E0H.$0((WE%#"-Y4"@C>5$L(WE
M.)"-X@`#F>@PP)WE!H`HX`>0*>`X@(WE/)"-Y0Q@E.`XP)WE`'"EX@Q@EN`@
MP:#A`<^,X0Q0H.$*(*#A`#"@XPC`C>4AP:#A#,"-Y0!/H.$($(WB`P"1Z`0`
M@.$%$('A`<"@X0"PH.&JK:#A@Z**X8*"H.$*@(CA`'"GX@A@EN``<*?B!I"@
MX0>@H.$PL(WE-,"-Y0#`H.-27XWB,`"5Z*R\'^4XD(WE/*"-Y0"@H.,$L)O@
M!<"LX`Q0H.$0<(WBP`"7Z`!@)N`)`*#A0)"-X@`#F>@!<"?@*,"=Y0:`*.`'
MD"G@"A"@X4"`C>5$D(WE#&";X$#`G>4`<*7B#&"6X"+!H.$#SXSA#%"@X0"0
MH..@K:#A@:**X8""H.$(P(WE"H"(X2/!H.$,P(WE`'"GX@A@EN`"3Z#A`'"G
MX@@PC>(,`)/H!["@X3"`C>*``9CH!"""X04P@^$"<"?@`X`HX!5>C>(P`)7H
M!J"@X0=@H.$(<*#A@(T?Y02`F.`(0*#A!9"IX`E0H.$XD(WB``.9Z!#`G>4&
M@"C@!Y`IX#B`C>4\D(WE#&"4X#C`G>4`<*7B#&"6X"#!H.$!SXSA#%"@X2@@
MC>4L,(WE"B"@X0`PH.,(P(WE(<&@X0S`C>4`3Z#A"!"-X@,`D>@$`(#A!1"!
MX4"@C>5$L(WE`<"@X0"PH.&JK:#A@Z**X8*"H.$*@(CA`'"GX@A@EN``<*?B
M!I"@X0>@H.$0L(WE%,"-Y0#`H.-67XWB,`"5Z$2^'^4XD(WE/*"-Y0"@H.,$
ML)O@!<"LX`Q0H.$H<(WBP`"7Z`!@)N`)`*#A0)"-X@`#F>@!<"?@,,"=Y0:`
M*.`'D"G@0("-Y420C>4*$*#A#&";X$#`G>4`<*7B#&"6X"+!H.$#SXSA#%"@
MX0"0H..@K:#A@:**X8""H.$(P(WE"H"(X2/!H.$,P(WE`'"GX@A@EN`"3Z#A
M`'"GX@@PC>(,`)/H!["@X1"`C>*``9CH!"""X04P@^$"<"?@`X`HX!9>C>(P
M`)7H!J"@X0=@H.$(<*#A&(\?Y02`F.`(0*#A!9"IX`E0H.$XD(WB``.9Z"C`
MG>4&@"C@!Y`IX#B`C>4\D(WE#&"4X#C`G>4`<*7B#&"6X"#!H.$!SXSA#%"@
MX3`@C>4T,(WE"B"@X0`PH.,(P(WE(<&@X0S`C>4`3Z#A"!"-X@,`D>@$`(#A
M!1"!X4"@C>5$L(WE`<"@X0"PH.&JK:#A@Z**X8*"H.$*@(CA`'"GX@A@EN``
M<*?B!I"@X0>@H.$HL(WE+,"-Y0#`H.-:7XWB,`"5Z-R_'^4XD(WE/*"-Y0"@
MH.,$L)O@!<"LX`Q0H.$P<(WBP`"7Z`!@)N`)`*#A0)"-X@`#F>@!<"?@$,"=
MY0:`*.`'D"G@"A"@X4"`C>5$D(WE#&";X$#`G>4`<*7B#&"6X"+!H.$#SXSA
M#%"@X0"0H..@K:#A@:**X8""H.$*@(CA","-Y2/!H.$,P(WE`'"GX@A@EN`"
M3Z#A`'"GX@@PC>(,`)/H!["@X2B`C>*``9CH!"""X04P@^$&H*#A`G`GX`.`
M*.`77HWB,`"5Z`=@H.$(<*#A](^?Y02`F.`(0*#A!9"IX`E0H.$0((WE%#"-
MY4"@C>5$L(WE.)"-X@`#F>@PP)WE!H`HX`>0*>`X@(WE/)"-Y0Q@E.`XP)WE
M`'"EX@Q@EN`@P:#A`<^,X0Q0H.$*(*#A`#"@XPC`C>4AP:#A#,"-Y0!/H.$(
M$(WB`P"1Z`0`@.$%$('A`<"@X0"PH.&JK:#A@Z**X8*"H.$*@(CA`'"GX@A@
MEN``<*?B!I"@X0>@H.$PL(WE-,"-Y0#`H.->7XWB,`"5Z#"_G^4XD(WE/*"-
MY0"@H.,$L)O@!<"LX`Q0H.$0<(WBP`"7Z`!@)N`)`*#A0)"-X@`#F>@!<"?@
M*,"=Y0:`*.`'D"G@"A"@X4"`C>5$D(WE#&";X$#`G>4`<*7B#&"6X"+!H.$#
MSXSA#%"@X0"0H..@K:#A@:**X8""H.$(P(WE"H"(X2/!H.$,P(WE`'"GX@A@
MEN`"3Z#A`'"GX@@PC>(,`)/H!["@X3"`C>*``9CH!"""X04P@^$"<"?@`X`H
MX`9=C>(P`)7H!J"@X0=@H.$(<*#A7(Z?Y02`F.`(0*#A!9"IX`E0H.$XD(WB
M``.9Z!#`G>4&@"C@!Y`IX#B`C>4\D(WE#&"4X#C`G>4`<*7B#&"6X"#!H.$!
MSXSA#%"@X0C`C>4AP:#A#,"-Y0!/H.$($(WB`P"1Z`0`@.$%$('A0*"-Y42P
MC>4!P*#A`+"@X2@@C>4L,(WE"B"@X0`PH.,0L(WE%,"-Y0#`H..JK:#A@Z**
MX8*"H.$*@(CA`'"GX@A@EN``<*?B!I"@X0>@H.%B7XWB,`"5Z)B]G^4$L)O@
M!<"LX`Q0H.$H<(WBP`"7Z#B0C>4\H(WE`&`FX`D`H.%`D(WB``.9Z`%P)^`P
MP)WE!H`HX`>0*>!`@(WE1)"-Y0Q@F^!`P)WE`'"EX@"@H.,,8);@(L&@X0//
MC.$,4*#A","-Y2/!H.$,P(WE"A"@X0)/H.$(,(WB#`"3Z`4P@^$#4*#AH*V@
MX8&BBN&`@J#A"H"(X0!PI^($((+A"&"6X`)`H.$&H*#A!6"@X0"0H.,`<*?B
M!["@X1"`C>*``9CH!'`GX`:`*.`9/HWB#`"3Z`=@H.$(<*#AN(R?Y0*`F.`P
M0(WE-%"-Y0@@H.$*0*#A`%"@XP.0J>`),*#A*,"=Y3B0C>(``YGH!H`HX`Q@
MDN"DS:#A!Y`IX(7"C.$X@(WE/)"-Y0C`C>6ES:#A#,"-Y3C`G>5`H(WE1+"-
MY0!PH^(,H);@`+"GXBB@C>4LL(WE(&&@X0BPC>(`#)OHA(*@X0%OAN$A<:#A
M!A"'X0B@BN$!<*#A"H"@X0`OH.$HL(WB``R;Z`(`AN$(H)K@`&"@X0>`H.$`
MD*#C`+"KX@H@H.$+,*#A,+"-X@`,F^AF'XWB`P"1Z`:@*N`(L"O@*&"-Y2QP
MC>7,BY_E0'"-XL``E^@0P)WE`("8X`I@)N`+<"?@`9"IX#A@C>4\<(WE#&"8
MX"2!H.$%CXCA!,^@X0R`C>4(P(WE`'"IXE@@C>5<,(WE)9&@X0`PH.,(4(WB
M,`"5Z`E0A>$(0(3A!8"@X1!@C>44<(WE!'"@X:*MH.&#HHKA@@*@X1!0C>(P
M`)7H.,"=Y0H`@.$HH(WB``::Z`B@BN$(<(WE#("-Y0>0B>$*<*#A#$"4X`!0
MI>(`L)3@`,"EXCBPC>4\P(WE6+"-X@`,F^@H8(WB8`"6Z`>P"^`(@(WB@`&8
MZ`=0!>`(8`;@`'"@XPF@"N`&D*#A&AZ-X@,`D>C4:I_E`&"6X`%PI^`08(WE
M%'"-Y05@BN$)<(OA0&"-Y41PC>4PP)WE$'"-XL``E^@,8);@`'"GX@:@H.$'
ML*#A(D&@X3B0C>(``YGH`T^$X0"0H.,C4:#A`@^@X0`@A.$$,(7A`U"@X0)`
MH.$0H(WE%+"-Y1`PC>(,`)/H0!"=Y:BMH.$!()+@B:**X0@0C>(#`)'HB&*@
MX0I@AN$00(WE%%"-Y02@@.$`,*/B!D"2X#APC>+``)?H!;"!X0MP!^`'L*#A
M`7"@X0I@!N`&H*#A`&"@X0!0H^(`,*#C$""-X@8`DN@P0(WE-%"-Y0)P!^!J
M7XWB,`"5Z-PIG^4!8`;@!""2X`4PH^`&0(KA!U"+X3"PC>(`#)OH`+"@XS@@
MC>4\,(WE"F"@X0MPH.%`0(WE1%"-Y3BPC>(`#)OH*%"=Y06@FN``L*OB"\"@
MX2@!H.$*L*#A"0^`X2D1H.$(+Z#A`H"`X0"0@>$)$*#A"`"@X2BPC>4LP(WE
M$)"-X@`#F>@H,(WB#`"3Z$#`G>6FK:#AAZ**X89"H.$,()+@`;")X0I`A.$`
MH(CA`#"CXA"@C>44L(WE!+"2X`#`H^(;7HWB,`"5Z#BPC>4\P(WE,#"-X@P`
MD^@0L(WB``R;Z`*@"N`!(*#A`[`+X``PH.,0@(WE%)"-Y0*0">#<*)_E`(`(
MX`0@DN`%,*/@"$"*X0E0B^$XH(WB``::Z`"@H.,P((WE-#"-Y4!`C>5$4(WE
M"8"@X3!0C>(P`)7H"I"@X0B@G>4*0)3@`%"EXB@`C>4L$(WE!+"@X07`H.$F
M`:#A!P^`X2<1H.$&+Z#A`F"`X0!P@>$'$*#A!@"@X0BPC>4,P(WE"#"-X@P`
MD^@H<(WBP`"7Z$#`G>6HK:#AB:**X8A"H.$,()+@`;"'X0I`A.$`H(;A"*"-
MY0RPC>4`,*/B!+"2X`#`H^)`L(WE1,"-Y3@PC>(,`)/H"+"-X@`,F^@"H`K@
M`2"@X0)P!^``(*#C;E^-XC``E>@P`(WE-!"-Y=@7G^4#L`O@!!"1X`4@HN`'
M4(OA0,"-X@`8G.@`P*#C`&`&X`@0C>4,((WE!D"*X0QPH.$X0(WE/%"-Y1#`
MG>4(4(WB,`"5Z`Q`E.``4*7B"V"@X02@H.$%L*#A*`&@X0B@C>4,L(WE"0^`
MX0@OH.$"@(#A.,"=Y0@PC>(,`)/H*1&@X::MH.$`D('AAZ**X3`0C>(#`)'H
MAD*@X0P@DN`*0(3A"("-Y0R0C>4(H(#A`#"CX@2`DN`)L('A`)"CXA"`C>44
MD(WE0#"-X@P`D^@!D*#A"S`#X`.PH.$*(`+@`("@X0`PH.,"H*#A"""-X@8`
MDN@'78WB,`"5Z`*0">#8)I_E!""2X`4PH^`!@`C@.""-Y3PPC>4(0(KA"5"+
MX1"@C>(`!IKH`*"@XT!`C>5$4(WE*,"=Y3A0C>(P`)7H#$"4X`!0I>()@*#A
M!;"@X0J0H.$F`:#A!*"@X0</@.$G$:#A!B^@X0)@@.$`<('A!Q"@X08`H.$H
MH(WE++"-Y0APC>+``)?H0,"=Y2@PC>(,`)/HJ*V@X8FBBN&(0J#A#""2X`&P
MA^$*0(3A`*"&X0B@C>4,L(WE`#"CX@2@DN``L*/B.*"-Y3RPC>40,(WB#`"3
MZ`BPC>(`#)OH`J`*X`$@H.$#L`O@`#"@XW)?C>(P`)7H"&"-Y0QPC>4"<`?@
MV"6?Y00@DN`%,*/@!U"+X3C`C>(`&)SH`,"@XP!@!N`0((WE%#"-Y09`BN$,
M<*#A0$"-Y410C>4PP)WE$%"-XC``E>@,0)3@`%"EX@M@H.$$H*#A!;"@X2@`
MC>4L$(WE*`&@X1"@C>44L(WE"0^`X0@OH.$"@(#A0,"=Y1`PC>(,`)/H*1&@
MX::MH.$`D('AAZ**X2@0C>(#`)'HAD*@X0P@DN`*0(3A$("-Y120C>4(H(#A
M`#"CX@2`DN`)L('A`)"CXC"`C>4TD(WE.#"-X@P`D^@!D*#A"B`"X`LP`^``
M@*#A`J"@X0.PH.$`,*#C$""-X@8`DN@=7HWB,`"5Z`*0">#4))_E`8`(X`0@
MDN`%,*/@"$"*X0E0B^$PH(WB``::Z`"@H.,X((WE/#"-Y0C`G>5`0(WE1%"-
MY3A0C>(P`)7H#$"4X`!0I>()@*#A!;"@X0J0H.$F`:#A!*"@X0</@.$G$:#A
M!B^@X0)@@.$`<('A!Q"@X08`H.$(H(WE#+"-Y0@PC>(,`)/H$'"-XL``E^A`
MP)WEJ*V@X8FBBN&(0J#A#""2X`&PA^$*0(3A`*"&X0B@C>4,L(WE`#"CX@2@
MDN``L*/B.*"-Y3RPC>4P,(WB#`"3Z`BPC>(`#)OH`J`*X`$@H.$#L`O@`#"@
MXW9?C>(P`)7H`G`'X-PCG^4$()+@!3"CX`=0B^$XP(WB`!B<Z`#`H.,`8`;@
M"""-Y0PPC>4&0(KA0$"-Y410C>4,<*#A"%"-XC``E>@HP)WE#$"4X`!0I>(+
M8*#A!*"@X06PH.$P`(WE-!"-Y2@!H.$(H(WE#+"-Y0D/@.$(+Z#A`H"`X4#`
MG>4(,(WB#`"3Z"D1H.&FK:#A`)"!X8>BBN$P$(WB`P"1Z(9"H.$,()+@"D"$
MX0B`C>4,D(WE"*"`X0`PH^($@)+@";"!X0"0H^(H@(WE+)"-Y3@PC>(,`)/H
M`9"@X0H@`N`+,`/@`("@X0*@H.$#L*#A`#"@XP@@C>(&`)+H'EZ-XC``E>@"
MD`G@V"*?Y0&`".`$()+@!3"CX`A`BN$)4(OA**"-X@`&FN@`H*#C.""-Y3PP
MC>40P)WE0$"-Y410C>4X4(WB,`"5Z`Q`E.``4*7B"8"@X06PH.$*D*#A)@&@
MX02@H.$'#X#A)Q&@X08OH.$"8(#A`'"!X0<0H.$&`*#A$*"-Y12PC>40,(WB
M#`"3Z$#`G>6HK:#A"'"-XL``E^B)HHKAB$*@X0P@DN`!L(?A"D"$X0"@AN$(
MH(WE#+"-Y0`PH^($H)+@`+"CXCB@C>4\L(WE*#"-X@P`D^@(L(WB``R;Z`*@
M"N`!(*#A`[`+X``PH.,(8(WE#'"-Y7I?C>(P`)7H`G`'X-@AG^4$()+@!3"C
MX`=0B^$XP(WB`!B<Z`#`H.,`8`;@$""-Y10PC>4&0(KA0$"-Y410C>4,<*#A
M$%"-XC``E>@PP)WE#$"4X`!0I>(+8*#A!*"@X06PH.$H`(WE+!"-Y2@!H.$0
MH(WE%+"-Y0D/@.$(+Z#A`H"`X4#`G>40,(WB#`"3Z"D1H.&FK:#A`)"!X8>B
MBN$H$(WB`P"1Z(9"H.$,()+@"D"$X1"`C>44D(WE"*"`X0`PH^($@)+@";"!
MX0"0H^(P@(WE-)"-Y3@PC>(,`)/H`9"@X0H@`N`+,`/@`("@X0*@H.$#L*#A
M`#"@XQ`@C>(&`)+H'UZ-XC``E>@"D`G@U""?Y0&`".`$()+@!3"CX`A`BN$)
M4(OA,*"-X@`&FN@`H*#C.""-Y3PPC>4(P)WE0$"-Y410C>4X4(WB,`"5Z`Q`
ME.``4*7B"8"@X06PH.$*D*#A)@&@X02@H.$'#X#A)Q&@X08OH.$"8(#A`'"!
MX0<0H.$&`*#A"*"-Y0RPC>40<(WBP`"7Z`@PC>(,`)/H0,"=Y:BMH.&)HHKA
MB$*@X0P@DN`!L(?A"D"$X0"@AN$`,*/B"*"-Y0RPC>4$H)+@`+"CXCB@C>4\
ML(WE?E^-XC``E>@"``#JH>O9;MR\&X_6P6+*"+"-X@`,F^@P,(WB#`"3Z`*@
M"N`!(*#A`[`+X``PH.,"<`?@-"`?Y00@DN`%,*/@!U"+X3C`C>(`&)SH`,"@
MXP!@!N`(((WE##"-Y09`BN%`0(WE1%"-Y0QPH.$(4(WB,`"5Z"C`G>4,0)3@
M`%"EX@M@H.$$H*#A!;"@X3``C>4T$(WE*`&@X0B@C>4,L(WE"0^`X0@OH.$"
M@(#A0,"=Y0@PC>(,`)/H*1&@X::MH.$`D('AAZ**X3`0C>(#`)'HAD*@X0P@
MDN`*0(3A"("-Y0R0C>4(H(#A`#"CX@2`DN`)L('A`)"CXBB`C>4LD(WE.#"-
MX@P`D^@!D*#A"B`"X`LP`^``@*#A`J"@X0.PH.$`,*#C"""-X@8`DN@"7(WB
M,`"5Z`*0">`X(1_E`8`(X`0@DN`%,*/@"$"*X0E0B^$HH(WB``::Z`"@H.,X
M((WE/#"-Y1#`G>5`0(WE1%"-Y3A0C>(P`)7H#$"4X`!0I>()@*#A!;"@X0J0
MH.$F`:#A!*"@X0</@.$G$:#A!B^@X0)@@.$`<('A!Q"@X08`H.$0H(WE%+"-
MY0APC>+``)?H$#"-X@P`D^A`P)WEJ*V@X8FBBN&(0J#A#""2X`&PA^$*0(3A
M`*"&X0B@C>4,L(WE`#"CX@2@DN``L*/B.*"-Y3RPC>4H,(WB#`"3Z`BPC>(`
M#)OH`J`*X`$@H.$#L`O@`#"@XX)?C>(P`)7H"&"-Y0QPC>4"<`?@."(?Y00@
MDN`H`(WE+!"-Y04PH^`'4(OA.,"-X@`8G.@`P*#C`&`&X!`@C>44,(WE!D"*
MX4!`C>5$4(WE#'"@X1!0C>(P`)7H,,"=Y0Q`E.``4*7B"V"@X02@H.$%L*#A
M*`&@X1"@C>44L(WE"0^`X0@OH.$"@(#A0,"=Y1`PC>(,`)/H*1&@X::MH.$`
MD('AAZ**X2@0C>(#`)'HAD*@X0P@DN`*0(3A$("-Y120C>4(H(#A`#"CX@2`
MDN`)L('A`)"CXC"`C>4TD(WE.#"-X@P`D^@!D*#A"B`"X`LP`^``@*#A`J"@
MX0.PH.$`,*#C$""-X@8`DN@A7HWB,`"5Z`*0">`\(Q_E`8`(X`0@DN`%,*/@
M"$"*X0E0B^$PH(WB``::Z`"@H.,X((WE/#"-Y0C`G>5`0(WE1%"-Y3A0C>(P
M`)7H#$"4X`!0I>()@*#A!;"@X0J0H.$F`:#A!*"@X0</@.$G$:#A!B^@X0)@
M@.$`<('A!Q"@X08`H.$(H(WE#+"-Y0@PC>(,`)/H$'"-XL``E^A`P)WEJ*V@
MX8FBBN&(0J#A#""2X`&PA^$*0(3A`*"&X0B@C>4,L(WE`#"CX@2@DN``L*/B
M.*"-Y3RPC>4P,(WB#`"3Z`BPC>(`#)OH`J`*X`$@H.$#L`O@`#"@XX9?C>(P
M`)7H`G`'X#0D'^4$()+@!3"CX`=0B^$XP(WB`!B<Z`#`H.,`8`;@!D"*X0@@
MC>4,,(WE#'"@X3``C>4T$(WE*,"=Y4!`C>5$4(WE"%"-XC``E>@,0)3@`%"E
MX@M@H.$$H*#A!;"@X2@!H.$(H(WE#+"-Y0D/@.$(+Z#A`H"`X4#`G>4(,(WB
M#`"3Z"D1H.&FK:#A`)"!X8>BBN$P$(WB`P"1Z(9"H.$,()+@"D"$X0B`C>4,
MD(WE"*"`X0`PH^($@)+@";"!X0"0H^(H@(WE+)"-Y3@PC>(,`)/H`9"@X0H@
M`N`+,`/@`("@X0*@H.$#L*#A`#"@XP@@C>(&`)+H(EZ-XC``E>@"D`G@."4?
MY0&`".`$()+@!3"CX`A`BN$)4(OA**"-X@`&FN@`H*#C.""-Y3PPC>40P)WE
M0$"-Y410C>4X4(WB,`"5Z`Q`E.``4*7B"8"@X06PH.$*D*#A)@&@X02@H.$'
M#X#A)Q&@X08OH.$"8(#A`'"!X0<0H.$&`*#A$*"-Y12PC>4(<(WBP`"7Z!`P
MC>(,`)/H0,"=Y:BMH.&)HHKAB$*@X0P@DN`!L(?A"D"$X0"@AN$(H(WE#+"-
MY0`PH^($H)+@`+"CXCB@C>4\L(WE*#"-X@P`D^@(L(WB``R;Z`*@"N`!(*#A
M`[`+X``PH..*7XWB,`"5Z`A@C>4,<(WE`G`'X#@F'^4$()+@!3"CX`=0B^$X
MP(WB`!B<Z`#`H.,`8`;@*""-Y2PPC>4&0(KA#'"@X4!`C>5$4(WE,,"=Y2A0
MC>(P`)7H#$"4X`!0I>(+8*#A!*"@X06PH.$0`(WE%!"-Y2@!H.$HH(WE++"-
MY0D/@.$(+Z#A`H"`X2@PC>(,`)/H0,"=Y0P@DN`0P(WB`!B<Z*:MH.&'HHKA
M"+"+X2D1H.&&0J#A`)"!X0I`A.$+H*#A"1"@X0@`H.$`,*/B!("2X`"0H^(X
M,(WB#`"3Z`H@`N`"H*#A`2"@X0'`C.$,,`/@`["@X0`PH.,P@(WE-)"-Y1"0
MC>(``YGH(UZ-XC``E>@"D`G@/"<?Y0"`".`$()+@!3"CX`A`BN$)4(OA,*"-
MX@`&FN@`H*#C.""-Y3PPC>5`0(WE1%"-Y0C`G>4X4(WB,`"5Z`Q`E.``4*7B
M"8"@X06PH.$*D*#A!*"@X2@`C>4L$(WE)@&@X0B@C>4,L(WE!P^`X2<1H.$&
M+Z#AJ*V@X0)@@.$`<('AB:**X8A"H.$'L*#A"D"$X0:@H.$(,(WB#`"3Z$#`
MG>4,()+@`,"@XR@0C>(#`)'H`#"CX@8`@.$$8)+@,%"-XC``E>@'$('A`5`%
MX`!PH^(X8(WE/'"-Y040H.$H8(WB8`"6Z(X_C>(,`)/H,*"-Y32PC>4+8`;@
M.+@?Y0*PF^`#P*S@"R"@X0PPH.$XP(WB`!B<Z`#`H.,*4`7@"Z"@X09PH.$,
ML*#A$,"=Y0!`!.`,`)+@JLV@X01@A>$!<(?AB\*,X4!@C>5$<(WE","-Y:O-
MH.$,P(WE0,"=Y0`0H^(,8)#@`'"AXB@!H.%`8(WE1'"-Y0D/@.$(<(WBP`"7
MZ"D1H.$(+Z#A`H"`X0"0@>&*0J#A0""-X@8`DN@$8(;A!A"1X!"`C>44D(WE
M`7"@X3!`C>(8`)3H"1V-X@,`D>@08(WB8`"6Z`4P(^`&0"3@!%"@X0-`H.$`
M,*#C`""BX@*`H.$@*1_E`""2X`(`H.$'(*#A`3"CX`,0H.$`,*#C0'"-Y42`
MC>4X<(WBP`"7Z"C`G>4$8";@!7`GX#A@C>4\<(WE#$"0X(+"H.$(P(WE.,"=
MY:*-H.$`4*'B@X*(X0Q@E.`,@(WE`'"EXBA@C>4L<(WE"'"-XL``E^@*#Z#A
M*D&@X2B@C>(`!IKH"&"&X0:0F>`+3X3A*U&@X1!PC>+``)?H`+"$X03`A>$H
ML(WE+,"-Y0QP)^``P*#CDE^-XC``E>@+8";@Y+D?Y0"@JN($L)O@"T"@X07`
MK.`,4*#A.)"-Y3R@C>4)`*#A":"@X4"0C>(``YGH,,"=Y0:`*.`'D"G@0("-
MY420C>4`L*#C#&"4X$#`G>4`<*7B#&"6X"+!H.$#SXSA#%"@X0C`C>4CP:#A
M#,"-Y0#`H..JK:#ABZ**X8""H.$*@(CA`'"GX@A@EN`"3Z#A`'"GX@@PC>(,
M`)/H!Z"@X2B`C>*``9CH!"""X04P@^$&D*#A`G`GX`.`*.`E7HWB,`"5Z`L0
MH.$'8*#AL+H?Y0APH.$$L)O@!<"LX`Q0H.$P((WE-#"-Y4"0C>5$H(WE"2"@
MX3B0C>(``YGH$,"=Y0:`*.`'D"G@.("-Y3R0C>4,8)O@.,"=Y0!PI>(,8);@
M(,&@X0'/C.$,4*#A`#"@XPC`C>4AP:#A#,"-Y0!/H.$($(WB`P"1Z`0`@.$%
M$('A`<"@X0"PH.&BK:#A@Z**X8*"H.$*@(CA`'"GX@A@EN``<*?B!I"@X0>@
MH.&67XWB,`"5Z!"PC>44P(WE`,"@XW2['^4XD(WE/*"-Y0"@H.,$L)O@!<"L
MX`Q0H.$P<(WBP`"7Z`!@)N`)`*#A0)"-X@`#F>@!<"?@*,"=Y0:`*.`'D"G@
M0("-Y420C>4*$*#A#&";X$#`G>4`<*7B#&"6X"+!H.$#SXSA#%"@X0"0H..@
MK:#A@:**X8""H.$(P(WE"H"(X2/!H.$,P(WE`'"GX@A@EN`"3Z#A`'"GX@@P
MC>(,`)/H!["@X1"`C>*``9CH!"""X04P@^$"<"?@`X`HX"9>C>(P`)7H!J"@
MX0=@H.$(<*#A2(P?Y02`F.`(0*#A!9"IX`E0H.$XD(WB``.9Z##`G>4&@"C@
M!Y`IX#B`C>4\D(WE#&"4X#C`G>4`<*7B#&"6X"#!H.$!SXSA#%"@X0C`C>4H
M((WE+#"-Y2'!H.$*(*#A`#"@XPS`C>4`3Z#A"!"-X@,`D>@$`(#A!1"!X4"@
MC>5$L(WE`<"@X0"PH.&JK:#A@Z**X8*"H.$*@(CA`'"GX@A@EN``<*?B!I"@
MX0>@H.$PL(WE-,"-Y0#`H..:7XWB,`"5Z`R]'^4XD(WE/*"-Y02PF^``H*#C
M!<"LX`Q0H.$H<(WBP`"7Z`!@)N`)`*#A0)"-X@`#F>@!<"?@!H`HX`>0*>`0
MP)WE0("-Y420C>4*$*#A#&";X$#`G>4`<*7B#&"6X"+!H.$#SXSA#%"@X0"0
MH..@K:#A@:**X0C`C>6`@J#A(\&@X0J`B.$,P(WE`D^@X0!PI^((,(WB#`"3
MZ`A@EN``<*?B!"""X04P@^$'L*#A)UZ-XC``E>@P@(WB@`&8Z`)P)^`#@"C@
M!J"@X0=@H.$(<*#AX(T?Y02`F.`(0*#A!9"IX`E0H.$XD(WB``.9Z"C`G>4&
M@"C@!Y`IX#B`C>4\D(WE#&"4X#C`G>4`<*7B#&"6X"#!H.$!SXSA#%"@X1`@
MC>44,(WE"B"@X0`PH.,(P(WE(<&@X0S`C>4`3Z#A"!"-X@,`D>@$`(#A!1"!
MX4"@C>5$L(WE`<"@X0"PH.&JK:#A@Z**X8*"H.$*@(CA`'"GX@A@EN``<*?B
M!I"@X0>@H.$HL(WE+,"-Y0#`H..>7XWB,`"5Z*2^'^4XD(WE/*"-Y0"@H.,$
ML)O@!<"LX`Q0H.$0<(WBP`"7Z`!@)N`)`*#A0)"-X@`#F>@!<"?@,,"=Y0:`
M*.`'D"G@"A"@X4"`C>5$D(WE#&";X$#`G>4`<*7B#&"6X"+!H.$#SXSA#%"@
MX0"0H..@K:#A@:**X8""H.$(P(WE"H"(X2/!H.$,P(WE`'"GX@A@EN`"3Z#A
M`'"GX@@PC>(,`)/H!["@X2B`C>*``9CH!"""X04P@^$"<"?@`X`HX`I=C>(P
M`)7H!J"@X0=@H.$(<*#A>(\?Y02`F.`(0*#A!9"IX`E0H.$XD(WB``.9Z!#`
MG>4&@"C@!Y`IX#B`C>4\D(WE#&"4X#C`G>4`<*7B#&"6X"#!H.$!SXSA#%"@
MX3`@C>4T,(WE"B"@X0`PH.,(P(WE(<&@X0S`C>4`3Z#A"!"-X@,`D>@$`(#A
M!1"!X4"@C>5$L(WE`<"@X0"PH.&JK:#A@Z**X8*"H.$*@(CA`'"GX@A@EN``
M<*?B!I"@X0>@H.&B7XWB,`"5Z!"PC>44P(WE`,"@XSBYG^4XD(WE/*"-Y0"@
MH.,$L)O@!<"LX`Q0H.$P<(WBP`"7Z`!@)N`)`*#A0)"-X@`#F>@!<"?@*,"=
MY0:`*.`'D"G@0("-Y420C>4*$*#A#&";X$#`G>4`<*7B#&"6X"+!H.$#SXSA
M#%"@X0"0H..@K:#A@:**X8""H.$(P(WE"H"(X2/!H.$,P(WE`'"GX@A@EN`"
M3Z#A`'"GX@@PC>(,`)/H!["@X1"`C>*``9CH!"""X04P@^$"<"?@`X`HX"E>
MC>(P`)7H!J"@X0=@H.$(<*#A9(B?Y02`F.`(0*#A!9"IX`E0H.$XD(WB``.9
MZ##`G>4&@"C@!Y`IX#B`C>4\D(WE#&"4X#C`G>4`<*7B#&"6X"#!H.$!SXSA
M#%"@X0C`C>4H((WE+#"-Y2'!H.$*(*#A`#"@XPS`C>4`3Z#A"!"-X@,`D>@$
M`(#A!1"!X4"@C>5$L(WE`<"@X0"PH.&JK:#A@Z**X8*"H.$*@(CA`'"GX@A@
MEN``<*?B!I"@X0>@H.$PL(WE-,"-Y0#`H..F7XWB,`"5Z*"WG^4XD(WE/*"-
MY02PF^``H*#C!<"LX`Q0H.$H<(WBP`"7Z`!@)N`)`*#A0)"-X@`#F>@!<"?@
M!H`HX`>0*>`0P)WE0("-Y420C>4*$*#A#&";X$#`G>4`<*7B#&"6X"+!H.$#
MSXSA#%"@X0"0H..@K:#A@:**X0C`C>6`@J#A(\&@X0J`B.$,P(WE`D^@X0!P
MI^((,(WB#`"3Z`A@EN``<*?B!"""X04P@^$'L*#A*EZ-XC``E>@P@(WB@`&8
MZ`)P)^`#@"C@!J"@X0=@H.$(<*#AS(:?Y02`F.`(0*#A!9"IX`E0H.$XD(WB
M``.9Z"C`G>4&@"C@!Y`IX#B`C>4\D(WE#&"4X#C`G>4`<*7B#&"6X"#!H.$!
MSXSA#%"@X1`@C>44,(WE"B"@X0`PH.,(P(WE(<&@X0S`C>4`3Z#A"!"-X@,`
MD>@$`(#A!1"!X4"@C>5$L(WE`<"@X0"PH.&JK:#A@Z**X8*"H.$*@(CA`'"G
MX@A@EN``<*?B!I"@X0>@H.$HL(WE+,"-Y0#`H..J7XWB,`"5Z`BVG^4XD(WE
M/*"-Y0"@H.,$L)O@!<"LX`Q0H.$0<(WBP`"7Z`!@)N`)`*#A0)"-X@`#F>@!
M<"?@,,"=Y0:`*.`'D"G@"A"@X4"`C>5$D(WE#&";X$#`G>4`<*7B#&"6X"+!
MH.$#SXSA#%"@X0"0H..@K:#A@:**X8""H.$(P(WE"H"(X2/!H.$,P(WE`'"G
MX@A@EN`"3Z#A`'"GX@@PC>(,`)/H!["@X2B`C>*``9CH!"""X04P@^$"<"?@
M`X`HX"M>C>(P`)7H!J"@X0=@H.$(<*#A-(6?Y02`F.`(0*#A!9"IX`E0H.$X
MD(WB``.9Z!#`G>4&@"C@!Y`IX#B`C>4\D(WE#&"4X#C`G>4`<*7B#&"6X"#!
MH.$!SXSA,""-Y30PC>4,4*#A"B"@X0`PH.,(P(WE(<&@X0S`C>4`3Z#A"!"-
MX@,`D>A`H(WE1+"-Y:JMH.&#HHKA!`"`X040@>&"@J#A"H"(X0&PH.$`H*#A
M`'"GX@A@EN``<*?B$*"-Y12PC>4'$*#A,+"-X@`,F^@0@(WB@`&8Z`>@*N`&
M`*#A"F"@X0"@H..N7XWB,`"5Z%B4G^4$D)G@"4"@X06@JN`*4*#A`*"@XPBP
M*^!`D(WB``.9Z"C`G>4&@"C@"Y`IX$"`C>5$D(WE#&"4X$#`G>4`<*7B#&"6
MX"+!H.$#SXSA#%"@X3@`C>4\$(WE"A"@X0C`C>4CP:#A#,"-Y0)/H.$(,(WB
M#`"3Z`0@@N$%,(/A`K"@X0/`H.&@K:#A@:**X8""H.$+78WB,`"5Z`J`B.&X
MDY_E`'"GX@A@EN``<*?B!)"9X`E`H.$`H*#C!B"@X0<PH.$HL(WE+,"-Y2B`
MC>*``9CH$,"-X@`8G.@(P"S@.)"-X@`#F>@'L"O@"X`HX`R0*>`PP)WE.("-
MY3R0C>4%H*K@#&"4X#C`G>4`<*KB#&"6X"#!H.$!SXSA0""-Y40PC>4,4*#A
M`#"@XPC`C>4AP:#A#,"-Y0!/H.$($(WB`P"1Z**MH.&#HHKA!`"`X040@>&"
M@J#A"H"(X0&PH.$`H*#A`'"GX@A@EN`PH(WE-+"-Y0!PI^('$*#A*+"-X@`,
MF^@P@(WB@`&8Z`>@*N`&`*#A"F"@X0"@H..R7XWB,`"5Z+22G^4$D)G@!:"J
MX`E`H.$*4*#A`*"@XPBP*^!`D(WB``.9Z!#`G>4&@"C@"Y`IX$"`C>5$D(WE
M#&"4X$#`G>4X`(WE/!"-Y0H0H.$`<*7B#&"6X"+!H.$#SXSA#%"@X:"MH.&!
MHHKA@(*@X0C`C>4CP:#A#,"-Y0J`B.$"3Z#A"#"-X@P`D^@`<*?B"&"6X`0@
M@N$%,(/A`'"GX@*PH.$#P*#A!B"@X0<PH.$M7HWB,`"5Z`"2G^4$D)G@"4"@
MX0"@H.-`((WE1#"-Y0`PH.,0L(WE%,"-Y1"`C>*``9CH,,"-X@`8G.@(P"S@
M.)"-X@`#F>@,D"G@*,"=Y06@JN`'L"O@#&"4X*+-H.$+@"C@@\*,X0C`C>4X
M@(WE/)"-Y:/-H.$,P(WE.,"=Y0!PJN(,H);@`+"GXBB@C>4LL(WE(&&@X0BP
MC>(`#)OH`6^&X8*"H.$A<:#A`$^@X02PAN$&P(?A"*"*X0M0H.$*@*#A#&"@
MX0!PH.,HL(WB``R;Z"A0C>4L8(WE"*":X"AAG^6VGXWB``.9Z`H`H.$(8);@
M$+"-X@`,F^@)<*?@0)"-X@`#F>@%H"K@`!"@XPJ`*.`(H*#A"&"-Y0QPC>4(
MD(WB``.9Z##`G>6@;:#A@6*&X0R`F."`0J#A"H"8X`9`A.$$L)C@"T"@X2+!
MH.$#SXSA","-Y2/!H.$,P(WE"+"-X@`,F^@";Z#A!J"*X0`#G>A0<(WBP`"7
MZ!`PG>4$@)C@*!"=Y0-@EN`@4(WB,`"5Z$@PC>(,`)/H`)"@XP`@DN`!0)3@
M&!"-X@,`D>@`<*#C"@"0X``PH.,.H*#A`%"@XP`0H.-$P)_E``..Z.3BG>4`
MP)SE#`!>X2!@BN4D<(KE"""*Y0PPBN480(KE'%"*Y1``BN44$(KE`@``&KO?
MC>+P3[WH'O\OX?CK_^O6P6+*0-$"````4.,>_R\!^$,MZ;0PG^4`D)/E``!9
MXR@```H`4-#E/0!5XP``51,!4*`3`%"@`Q0``!H`0)GE``!4XPX```H!@*#A
M`'"@X0E@H.$$`*#A!Q"@X04@H.%O[/_K``!0XP(``!H%,-3G/0!3XPP```H$
M0+;E``!4X_/__QH$`*#A^$.]Z![_+^$`4*#A`3#UY3T`4^,``%,3^___&@50
M8.#C___J!F!IX$9AH.$`8(CE`0"%X@``A.#X0[WH'O\OX0D`H.'M___J.-$"
M`'!`+>D`0*#A=&"?Y0`PEN4(T$WB!#"-Y6A0G^4$`*#A#1"@X<+__^L``%#C
M#```"@`0G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""SY0``4N,$
M(`/E^___&NW__^H$()WE`#"6Y0,`4N$"```:"-"-XG!`O>@>_R_AHNO_ZT#1
M`@`XT0(`\$\MZ0%`H.$`(-'E\%&?Y3T`4N,!0($"`#"5Y1303>(`8*#A!`"@
MX0PPC>73Z__K"!"-X@!PH.$&`*#AF?__ZP"@4.(^```*S.O_ZP``5^$U``":
M"("=Y:B1G^4(@:#A`!#6Y3T`4>,``%$3`1"@$P`0H`,%```*!A"@X0$P\>4]
M`%/C``!3$_O__QH!$&;@`@"'X@$`@.``<)GEI>O_ZP``4.,(`(?G6"&?Y5$`
M``H`,-;E``!3XST`4Q,`()+E"!"=Y0$1DN<!8(;B`##!Y08```H!(('B`3#6
MY```4^,]`%,3`A"@X0$PPN3Y__\:/3"@XP$@H.$`,,'E`3#4Y```4^,!,.+E
M^___&@``H.,,()WE`#"5Y0,`4N$W```:%-"-XO!/O>@>_R_A`2!*X@$PU.0`
M`%/C`3#BY?O__QKQ___JO)"?Y0"PF>4`()OE``!2XR0```H+,*#A!""SY0``
M4N,!H(KB^___&@(0BN(!$:#AD#"?Y0`@D^4``%+C"@``"@L`H.%&Z__K``!0
MXP``B>47```*"H&@X0`@H.,!,(KB`R&`YPB@C>6K___J`2"@XP$`H.$`((/E
M7>O_ZP`P4.($,(WE"@``"@J!H.$+$*#A"""@X0OK_^L$,)WE`P"@X0`PB>7K
M___J`J"@X0@0H./>___J``#@X\/__^H?Z__K0-$"`#C1`@!HT0(`\$$MZ2Q1
MG^4`,)7E>-!-X@!P4.)T,(WE`@``"@`PU^4``%/C!@``&G0@G>4`,)7E`P!2
MX3X``!IXT(WB\$&]Z![_+^$QZ__K`&!0XO7__PH&`*#AA^O_ZP``4.,D```*
M$R#0Y2X`4N,F```*$T"`X@<`H.$]Z__K`("@X00`H.$ZZ__K``"(X`(`@.(E
MZ__K`("@X0$0H.,`(.#CF#"?Y01`C>4`<(WE/^O_ZP@0H.$#`*#C"""-XGKK
M_^L!`'#C"`"@X0,```H8,)WE#SH#X@$)4^,4```*Z^K_ZP@`H.'(ZO_K!@"@
MX6+K_^L``%#CVO__&@8`H.%YZ__K!P"@X<_J_^O'___J%"#0Y0``4N/.__\*
M+@!2X]/__QH5(-#E``!2X\G__PK/___JL___Z^G__^K.ZO_K0-$"`,B*`0!P
M0"WI#$&?Y0``E.5GZ__K@#"0Y0``E.4$8)/E8^O_ZV50T.4``)3E8.O_ZP0P
MD.6P,=/A?U`%XH,[H.$C6(7ALE#&X0``E.58Z__K@#"0Y0``E.4$4)/E5.O_
MZ[@0G^4`(*#C^NK_ZQP`A>4``)3E3NO_ZX`PD.4``)3E!%"3Y4KK_^O@-)#E
M``"4Y2`PA>5&Z__K@#"0Y0``E.4$4)/E0NO_Z_PPD.4``%/C`P``"@``E.4]
MZ__K_#"0Y7`PD^4D,(7E``"4Y3CK_^L`4*#C@#"0Y00PD^4``)3E*%"#Y3+K
M_^N`,)#E!#"3Y0``E.484(/E+>O_ZX`PD.4``)3E!$"3Y2GK_^L8,I#E+#"$
MY7!`O>@>_R_A2-$"`-B-`0`X0"WI>$"?Y0!0H.$``)3E'NO_ZP40H.%"+X#B
M`P"@XQ3K_^L``%#C`@``"@``H.,X0+WH'O\OX0``E.43Z__K&#&0Y0\Z`^(!
M"5/C!0``"@``E.4-Z__K&#&0Y0\Z`^(*"E/C\/__&@4`H.$"$*#CW.K_ZP$`
M<.(``*`S.$"]Z![_+^%(T0(`\$`MZ=10G^4!VDWB#-!-X@`PE>4!RHWB!,",
MX@!@H.$!<*#AN`"?Y000C>*T()_E`#",Y6;J_^L``%#C'P``V@%`0.((,(WB
M!,"#X`0@7.4``%+C%P``"@!`H.$$`(WB+Q"@XP0@H.&YZO_K``!0XQ(```IP
M,)_E``"3Y>'J_^L&$*#A!""-X@0PH.'"ZO_K`3J-X@0P@^(`()/E`#"5Y0,`
M4N$,```:`=J-X@S0C>+P0+WH'O\OX0``5./F__\:)#"?Y0``D^7.ZO_K!A"@
MX0<@H.$[ZO_K[/__ZBKJ_^M`T0(`T(H!`/\/``!(T0(`"$`MZ1PPG^4``)/E
MP>K_ZQ0PG^44$)_E%""?Y77J_^L(0+WH'O\OX4C1`@!,B@$`X(H!``06`0`0
M0"WI/$"?Y0C03>(``)3ELNK_Z^O__^L``)3EK^K_ZP`@H.,@,)_E!""-Y0`P
MC>48$)_E&""?Y7CJ_^L(T(WB$$"]Z![_+^%(T0(`V(T!`/R*`0#,?P$`<$`M
MZ=!0G^4"VDWB(-!-X@`PE>4"*HWB'"""X@`P@N4RZO_KM#"?Y10@C>()`(WH
M"""-Y0(`H.$!$*#CH""?Y:`PG^4^ZO_K``!0XQT``+H!.HWB(#"#X@@P0^((
M`)WE`Q"@X0$JH.,,,(WE^.G_ZP!`4.(3``"Z`0"$X@_J_^L`8%#B$0``"@P0
MG>4$(*#AR.G_ZP`PH.,&`*#A!##&YP(ZC>(<,(/B`""3Y0`PE>4#`%+A!P``
M&@+:C>(@T(WB<$"]Z![_+^$``*#C\___Z@8`H.'Q___JR^G_ZT#1`@`@BP$`
M`1```!2+`0##___J\$\MZ<`QG^4!VDWB'-!-X@`PD^4!*HWB%"""X@!`H.$!
M8*#AI`&?Y1`0C>(`,(+EPOW_ZR\0H.,`4*#A!`"@X?KI_^L``%#C#@``"H`!
MG^4$$*#A#_[_ZP0`H.$!.HWB%#"#X@`@D^5<,9_E`#"3Y0,`4N%3```:`=J-
MXAS0C>+P3[WH'O\OX00`H.'AZ?_K0!&?Y0"0H.$&`*#A%NK_ZP"P4.+H__\*
M+'&?Y2R!G^4LH9_E+&&?Y0`PV^4``%/C!["@`0``5>,$```*!0"@X0L0H.%F
MZ?_K``!0XR@```H+`*#AR^G_ZP`PB^`!,%/E+P!3XP<``!H`P*#C`3!`X@,P
MB^``P,/E`1!SY2\`4>,!`$#B^O__"@$PB>(``(/@"`!0X<C__\H!$*#C`2J@
MX[0PG^4`L(WE!*"-Y0A`C>44`(WBPNG_ZP``EN41ZO_K%!"-XD(O@.(#`*#C
M^^G_ZP``4.,%```:``"6Y0GJ_^L8,9#E#SH#X@()4^,&```*``"@XTP0G^7;
MZ?_K``!0XP"PH.''__\:J___ZA0`C>(!$*#CT>G_ZP``4./S__\:%!"-XA@`
MG^6V_?_K%`"-XJGI_^ND___J4^G_ZT#1`@`HBP$`-(L!`$2+`0`DBP$`_P\`
M`%"+`0!(T0(`2(L!```PT.4``%/C'O\O`0$@@.(O`%/C`@"@`0$PTN0``%/C
M^O__&A[_+^$X0"WI`$!0XBP```H`4-3E``!5XRD```IXZ?_K`0!`X@`PA.`#
M`%3A"P``*@`@U.<O`%+C*P``&@$@0^(#``#J`!#2Y2\`4>,!($+B)0``&@0`
M4N$",*#A^/__&@,`5.$4```*`3!#X@,``.H`$-/E+P!1XP$P0^("```:`P!4
MX0,@H.'X__\Z`B!DX`(P@N(!"E/C$```B@00H.$!((+B=`"?Y0$ZH.,2Z?_K
M:`"?Y3A`O>@>_R_A+P!5XQ,``!H"`*#C.^G_ZP`P4.(N(*`3`P"@$;`@PQ'T
M__\:``"@XSA`O>@>_R_A`2!#X@,``.H`$-+E+P!1XP$@0N+8__\*`@!4X0(P
MH.'X__\ZTO__Z@@`G^5.Z?_KY/__ZFS1`@!0BP$`$$`MZ5#AG^4PT$WB#P"^
MZ`C`C>(/`*SH#P"^Z`\`K.@X09_E`"">Y0`PE.4P`9_EL"#,X2PPC>4D_?_K
M)`&?Y2+]_^L@`9_E(/W_ZQP!G^4>_?_K&`&?Y1S]_^L4`9_E&OW_ZQ`!G^48
M_?_K#`&?Y1;]_^L(`9_E%/W_ZP0!G^42_?_K``&?Y1#]_^O\`)_E#OW_Z_@`
MG^4,_?_K!!"-XO``G^76_/_K`!!0XM``GQ4I_?\;!!"-XMP`G^70_/_K`!!0
MXM0`GQ4C_?\;!!"-XLP`G^7*_/_K`!!0X@L```J4`)_E'/W_ZX0`G^6T$)_E
M&?W_ZRP@G>4`,)3E`P!2X10``!HPT(WB$$"]Z![_+^$$$(WBD`"?Y;G\_^L`
M$%#B`@``"E0`G^4+_?_K[?__ZAD`C>)T$)_E"B"@XS?I_^L``%#CY___&B,0
MC>(L`)_E`?W_Z^/__^J@Z/_K6(H!`$#1`@!4BP$`8(L!`&B+`0!TBP$`?(L!
M`(R+`0`HBP$`F(L!`*2+`0"PBP$`-(L!`+R+`0#(BP$`U(L!`.B+`0#\BP$`
M"(P!`#B,`0`8C`$`+(P!`#!`+>EH4)_E:$"?Y0``E>4`,)3E#-!-X@$`<.,$
M,(WE!@``"@0@G>4`,)3E`P!2X0X``!H,T(WB,$"]Z![_+^$T`)_E#1"@X8#\
M_^L``%#C!```"@``T.4``%#C,`!0$P$`H!,``*`#``"%Y>S__^IMZ/_K+-$"
M`$#1`@"8BP$`"$`MZ4?H_^M`Z/_K``!0XP``D!4(0+WH'O\OX?!'+>G\X)_E
M`'"@X0\`ON@`0*#A.-!-XAC`C>(/`*SHY("?Y0<`GN@`,)CE``!4XP<`C.@T
M,(WE%P``"AA0C>+(D)_E!@``Z@<0H.$BZ/_K``!0XQ<```H$0+7E``!4XPT`
M``H$`*#A%!"-XE#\_^L`8%#B`@``"@`PUN4``%/C\/__&@0`H.$'$*#AGOS_
MZP1`M>4``%3C\?__&C0@G>4`,)CE`P!2X14``!HXT(WB\$>]Z![_+^$'`*#A
M<NC_ZP"@H.$&`*#A;^C_ZP``BN`"`(#B6NC_ZP"@H.&``HWH"&"-Y0$0H.,`
M(.#C(#"?Y73H_^L$`*#A"A"@X8+\_^O4___J(>C_ZWR*`0!`T0(`1(L!`$B+
M`0#P3RWID,F?Y8'<3>(TT$WB`%"@X0<`G.@X,(WB#$",X@<`@^@/`+3H4."-
MX@\`KN@#`)3H),",X@,`CNA<N9_E!P"<Z$0PC>('`(/H`,";Y8$\C>(L,(/B
M-!"-XD`)G^4`P(/E#/S_ZP!`4.("```*`##4Y0``4^,!`0`:DO__ZP!`4.)$
M8(T"1P``"@0`H.$WZ/_K@`"@X0$`@.(BZ/_K`##4Y0``4^,`<*#A`&"@$0D`
M``H`,(WE!@"@X>0XG^4!$*#C`"#@XSCH_^L!,/3E``!3XP)@AN+U__\:4`"=
MY0``4.-00(T2`P``&A```.H$`+3E``!0XPT```HT$(WBY?O_ZP!@4.+X__\*
M`##6Y0``4^/U__\*4?W_ZP``4./R__\*!@"@X2;H_^L`@%#B*0``&CA`G>4`
M`%3C)0``"@`PU.4``%/C`6"@$PD``!H@``#J$SZ-X@8Q@^#X0!/E``!4XQL`
M``H`,-3E``!3XP%@AN(7```*!`"@X3C]_^L``%#C\O__"@0`H.$-Z/_K``!0
MX^[__PH`@*#A#@``Z@CH_^L``%#CO```&@0`EN0``%#CM@``"C00C>*V^__K
M`#!0XOC__PH`,-/E``!3X_7__PKQ___J`("@XP@`H.'CY__K`$"@X0<`H.'@
MY__K``"$X`%+@.($0(3B!`"@X<GG_^L`8*#AG#>?Y9RGG^4(,(WE`1"@XP`@
MX..0-Y_E`("-Y0QPC>4$H(WEW^?_ZP8`H.$'':#CZ.?_ZP$`<.,:```*;'>?
MY0``E^4HZ/_K!A"@X4(O@.(#`*#C'NC_ZP``4.,?```*3">?Y0`PE>4``)+E
M`1"@XP!@C>4\)Y_EZ.?_ZP``H..!/(WB+#"#X@`@D^4`,)OE`P!2X;T!`!J!
MW(WB--"-XO!/O>@>_R_AN^?_ZP`@D.41`%+CX/__"O06G^4`,)7E``"1Y00@
MC>4`8(WE`1"@X^0FG^71Y__K``"@X^?__^H``)?E`.C_ZQ@QD.4/.@/B`0E3
MX]G__QH``)?E^N?_ZR"!D.4XY__K``!8X=/__QH``)?E].?_ZQ@QD.6#.Z#A
M#@)3X\W__QH$`*#A?.?_ZS00C>(`0*#A@`:?Y53[_^L``%#CCP$`"@!PE>6;
MY__K`!"@X0<`H.%]_?_K`'!0XH@!``H'`*#A?^?_ZP,`4.,`@*#A"P``V@0`
M0.(``(?@/!:?Y0_G_^L``%#C!0``&@0`6.,W`0`*"("'X`4P6.4O`%/C,P$`
M"J7^_^L`$%#B!```&@<`H.%6Y__K`#!0XB@PC>4U```:^!6?Y?@%G^6%^__K
M7N?_Z_"%G^4(`(WE0`2-Z`R`C>4$`*#A`1"@XP`@X./8-9_E:N?_ZP!PH.,.
M``#J9.?_ZP`PD.41`%/C$```&D[G_^L!<(?B"`"-Y0QPC>5`!(WH$("-Y04@
MH.$$`*#A`1"@XY@UG^59Y__K!`"@X0<=H.-BY__K`0!PXP!0H.'J__\*!@"@
MX>CF_^L$$*#A,`6?Y5_[_^L$`*#AFO[_ZP0`H.&`___JE_[_ZP0`H.%-Y__K
M?/__Z@T`H.-$19_E_O[_Z@!`H.'X_O_J`E"@XP`PX.,1(.#C`%"-Y0SG_^M+
M'XWB*`"=Y08@H./&YO_K+#'=Y0``4^,"```:+3'=Y4,`4^,)`0`*`%"@XP`@
MH.,`,*#C*`"=Y0!0C>7\YO_K`""@XP`PH.,`$*#CD""-Y90PC>68((WEG#"-
MY0`PH./$!)_EQ"2?Y6@`C>5L$(WE<""-Y70PC>4`D*#C`!"@XP`PH..HA)_E
MJ`2?Y:@DG^5X@(WE?)"-Y8`@C>6$,(WEB`"-Y8P0C>7@4(WE+$"-Y:!PC>(H
M`)WE2Q^-X@(IH..9YO_K`%!0XE4``-K%'Z#A@3&@X:4^@^&%P:#A'#"-Y1C`
MC>48D(WB``.9Z`"0H..0,(WB#`"3Z`*`F.`)`%/A"`!2`04`H.&8,(WB#`"3
MZ`$``)H!()+B`#"CXJ#.H.&!P8SAH1Z@X2#`C>4D$(WE(!"-X@,`D>@"`)#@
M`Q"AX``@H.$!,*#AX`"=Y0``4..8((WEG#"-Y9"`C>64D(WE+0``"D`P8.(#
M`%7A`Y"@H060H+%H,(WB.`"`X@``@^`)(*#A2Q^-XG;F_^O@,)WE`S")X$``
M4^/@,(WEQ/__&DL_C>)H`(WB!5!IX`F0@^`%Z/_K/P!5XQ```-H%0*#A0(")
MXD`02.)`(*#C!P"@X63F_^M`0$3B:`"-XOKG_^L_`%3C0("(XO7__\I`4$7B
M)3.@X0$@@^(#4T7@`I.)X`D0H.$'`*#A!2"@X4@PH.-^YO_KX%"-Y:7__^I+
MGXWBX___ZB@`C>(1`)#H^.;_ZW\0X..0<)WEIR&@X3\@`N(!,(+B.`!3XQ,^
MC>(",(/@.0""XI`00^5H,(WBF("=Y0``@^!D``#*-R!BX@`0H..NYO_K*,R@
MX2@8H.$H)*#A)SR@X2?HH.%H`(WBWW#-Y2=TH.';@,WEV,#-Y=D0S>7:(,WE
MW##-Y=W@S>7><,WEQ>?_ZV@0G>5P()WE>."=Y2%XH.$A/*#A[Q#-Y2$4H.&(
M`)WE[7#-Y>X0S>4B?*#A(AB@X?,@S>4B)*#A@,"=Y?(@S>4N)*#A+HR@X?!P
MS>7V(,WE+GB@X2`DH.$!G(WB\1#-Y??@S>4L&*#A+.R@X?2`S>7U<,WE((R@
MX2QTH.'[P,WE_B#-Y2#(H.$3+HWB^G#-Y?R`S>4)4*#A[##-Y?C@S>7Y$,WE
M_P#-Y?W`S>7L<(WB,8!"X@```.H!,/?E`#"-Y04`H.$!$*#C`"#@XV0QG^5:
MYO_K"`!7X0)0A>+U__\:`,"@XWPQG^5`!(WH##"-Y0B0C>4$`*#A`1"@XP`@
MX..$,9_E*,'-Y4SF_^OW_O_J!%"5Y0``5>/(_O\*!0"@X3?F_^L#`%#CQ/[_
MF@0`0.(``(7@5!&?Y<CE_^L``%#C!7"@`;W^_^H_(&+B`!"@XTGF_^MH`(WB
M;N?_ZP`PH..@,(WEI#"-Y:@PC>6L,(WEL#"-Y;0PC>6X,(WEO#"-Y<`PC>7$
M,(WER#"-Y<PPC>70,(WEU#"-Y8C__^HN,=WE00!3X_+^_QHO,=WE0P!3X^_^
M_QHP,=WE2`!3X^S^_QHQ,=WE10!3X^G^_QH`4(WE*%"=Y0`PX.,%`*#A.2#@
MX^;E_^M+'XWB!0"@X2D@H..@Y?_K;#"?Y4LOC>((((WE##"-Y4`$C>@$`*#A
M`1"@XP`@X.-P,)_E".;_Z[/^_^H`<)7E=/[_ZK;E_^N8B@$`0-$"`"B+`0!$
MC`$`6(P!`%"+`0!,C`$`2-$"`%#1`@#@C`$`8(P!`"R.`0"<C`$`.(P!`)B+
M`0#8C0$`O(P!`,R,`0`\C`$``2-%9XFKS>_^W+J8\.'2PW94,A"LC`$`I(P!
M`/!/+>F`,Y_E@'.?Y0`PD^4,T$WB``"7Y00PC>4SYO_K`3"@XPT0H.%A,,#E
M8`.?Y9CY_^L``%#C`@``"@`PT.4Q`%/CAP``"I'\_^L``)?E)N;_ZSP3G^4!
M(*#C"S"@X[;E_^L``%#C+&.?Y2X```KT+Q;E$#"0Y0$`4N,8@)/E*0``V@!0
MH.,!0*#C_)*?Y0D``.H0$)+E"@"@X4KE_^L``%#C]#\6Y1P``!H!0(3B!`!3
MX0%0A>(8``#:``"7Y0KF_^L($*#A!2"@X0`PH./BY?_K`+!0X@\```H`()OE
MN#*?Y0@`DN7P'Q;E`#`#X`$+4^,$H9'GY?__"@``F>7ZY?_K`!";Y0`@H.,"
M,*#C;^7_ZP`0H.'>___J]#\6Y0$@0^(%`%+A0@``"@``E^7NY?_K:!*?Y0$@
MH.,#,*#C?N7_ZP!`4.)`4I_E"@``"@``E>7EY?_K$#"4Y40BG^4`$)/E4>7_
MZQ`PE.4`,)/E"#"3Y0$%$^-T```:``"7Y=KE_^L@$I_E`2"@XP,PH.-JY?_K
M`%!0XO!!G^4*```*"`*?Y0T0H.$Z^?_K`(!0X@``E.5-```*S.7_ZQ`PE>4(
M(*#A`!"3Y3CE_^L``)?EQN7_ZP`PH.,-$*#A83#`Y<P!G^4K^?_K``!0XP!`
MH.'L#P;EE)&?Y9R!G^4=```*!QV@XW3E_^L!,(#B$0!0XP$`4Q-6``"*;#&?
MY00@G>4`,)/E`P!2X5```!H,T(WB\$^]Z![_+^$!`%/CNO__V@%`H.,``)?E
MJ.7_ZP@0H.'OY/_K]#\6Y0%`A.($`%/A]___RK#__^H!,-#E``!3XW7__PIS
M___J\`\8Y=[\_^L``%#C[`\(Y38```H0,)7E`""3Y00QG^4($)+E`3`#X`$+
M4^,A```:$`"2Y?!/%N4$$*#AW.3_ZQ`PE>4`P)/EV""?Y0@PG.4#(`+@`0M2
MXP!@H.$`0)3E"P``&A`@G.4$$*#A!C"@X<@`G^4QY?_K?N7_ZQ`@E>7P/Q;E
M``"2Y0`0D^5W^O_KK___Z@``E^5VY?_K$#"5Y0`@H.,`$)/E`C"@X^KD_^L`
M(*#AZ___Z@``F>5MY?_K$#"5Y00@H.$`$)/E`C"@X^'D_^O6___J``"5Y67E
M_^L0,)3E`!"3Y2GE_^N$___J3`"?Y1'E_^N_Y/_K\#\8Y00@H.$`$)/E`#"@
MX30`G^4*Y?_K0-$"`$C1`@!\BP$`-(T!`&#Q`@``!"``/(T!`$"-`0!(C0$`
M-(L!`"B+`0!PC0$`3(T!`)B-`0`X0"WI`%"@X6?[_^L`,-#E``!3XP!`H.$%
M```*`2"`XB\`4^,"0*`!`3#2Y```4^/Z__\:$OS_ZP``4.,``%43!P``"@`P
MU>4``%/C!```"@0`H.$<$)_E9^3_ZP``5.$!```*.$"]Z![_+^$%`*#A.$"]
MZ'#Y_^I8C`$`$$`MZ2A`G^4``)3E)^7_ZP`0X..GY/_K``"4Y2/E_^L0$)_E
M`""@XPOE_^L00+WH'O\OX4C1`@`,:P$`"$`MZ10PG^4#,(_@``!3XP`PDQ5Z
MY/_K"$"]Z![_+^'03`$`^$,MZ5A@G^584)_E!F"/X`50C^`&8&7@`'"@X0&`
MH.$"D*#A-.3_ZT9AL.$*```*!%!%X@!`H.,!0(3B!#"UY0<`H.$($*#A"2"@
MX0_@H.$3_R_A!@!4X?;__QKX0[WH'O\OX6!*`0!82@$`'O\OX0(1(>(```#J
M`C$CXC!`+>F!0*#A@U"@X04`-.$"`#`!`,"4$0+`E1'$RO`1Q<KP$8P```JD
M2J#AI5ITX`!09;(&``#:!4"$X`(@(.`#,"'@```BX`$0(^`"("#@`S`AX#8`
M5>,P0+V('O\O@0(!$>,!%J#A`<:@XR$6C.$!```*``!PX@`0X>("`1/C`S:@
MX2,VC.$!```*`"!RX@`PX^(%`#3A:0``"@%`1.(@X'7B!0``NA+.H.$R!9#@
M`!"AXA,.D.!3%;'@!@``ZB!01>(@X([B`0!2XQ/.H.$"P(PC4P60X,,?L>`"
M40'B`@``6@#`?.(``/#B`!#AX@$&4>,/```Z`@91XP8``#JA$+#A8`"PX6S`
MH.$!0(3BA"J@X0$%<N-K```J`@%<XZ#`L`$``+#B!!JAX`40@>$P0+WH'O\O
MX8S`L.$``+#@`1"AX`$&$>,!0$3B\O__&@``,>,4,*`3-#"@`P`0H`$``*`#
M`2"@X0$(4N,B**`A$#!#(@$,4N,B)*`A"#!#(A``4N,B(J`A!#!#(@0`4N,"
M,$,BHC!#,*(Q0^`@(%/B!P``J@P@DN($``#:%,""X@P@8N(1#*#A,1*@X00`
M`.H4((+B(,!BTA$2H.$P'('1$`*@T0-`5.`$&H&@!1"!H3!`O:@>_R^A!$#@
MX1]`5.(/``"J#$"4X@8``,H40(3B("!DXC`$H.$1`H#A,12%X3!`O>@>_R_A
M#$!DXB`@9.(P`J#A$02`X040H.$P0+WH'O\OX3$$H.$%$*#A,$"]Z![_+^$`
M`#3C`38CX@$6(0(!0(0"`5!%$H___^K$RO#AQ<KP$1T```H%`#3A`@`P`00`
M``H`P)3A`Q"@`0(`H`$P0+WH'O\OX0,`,>$`$*`3``"@$S!`O1@>_R\1I,JP
MX00``!J``+#A`1"QX`(1@2,P0+WH'O\OX0%%E.(!%H$R,$"].![_+S$"40'B
M?Q2%XP\6@>,``*#C,$"]Z![_+^'$RO#A`Q"@$0(`H!'%RO`!`3"@$0`@H!$!
M1I#A`U:2`0,`,0$"%X$3,$"]Z![_+^$``##C`!"@`Q[_+P$P0"WI`4N@XS)`
MA.(`4*#C`!"@XX;__^H``##C`!"@`Q[_+P$P0"WI`4N@XS)`A.("41#B``!@
M0@`0H.-\___J@""PX<(1H.%A$*#A`@Z@X?\T$A+_!#,3#A,A$A[_+Q$``#+C
M_P0S$Q[_+P$P0"WI#DV@XP)1`>("$<'C;/__Z@$@D.$>_R\!,$`MZ0!0H.,&
M``#J`2"0X1[_+P$P0"WI`E$1X@$``%H``'#B`!#AX@%+H.,R0(3B(<NPX43_
M_PH#(*#CK,&PX0,@@A*LP;#A`R""$JPA@N`@,&+B$,.@X3`"H.$1`X#A,1*@
MX0)`A.`W___J`,#@XP(``.H!P*#C````Z@'`H.,$P"WE@<"@X<S*\.&#P*#A
MS,KP$0X```H$T(WB@<"0X8/`D@$#`#$1`@`P`0``H`,>_R\!``!PXP,`,>$#
M`%%1`@!0`<,/H"'##^`Q`0"`XQ[_+^&!P*#AS,KPX0$``!H!QI#A!```&H/`
MH.',RO#AZ/__&@/&DN'F__\*!`"=Y![_+^$`P*#A`@"@X0P@H.$!P*#A`Q"@
MX0PPH.'____J`4`MZ=3__^L``%#C``!P0P%`O>@>_R_A".`MY??__^L!`*`#
M``"@$PC@G>0>_R_A".`MY?'__^L!`*`S``"@(PC@G>0>_R_A".`MY>O__^L!
M`*"3``"@@PC@G>0>_R_A".`MY=[__^L!`*"3``"@@PC@G>0>_R_A".`MY=C_
M_^L!`*`S``"@(PC@G>0>_R_A"$`MZ0A`O>@>_R_A`0`"`'!E<FQX<VDN8P``
M`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@``````R.`0`<C@$`
M)(X!`"R.`0`TC@$`2(X!```````$C@$`)(L!``````#\BP$``(P!`/B-`0`L
MBP$``(X!``````#DC0$`[(T!```````E<R\E<P```"]P<F]C+W-E;&8O97AE
M``!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z
M.D)/3U0`````+W!R;V,O)6DO)7,`97AE`"X```!005)?5$5-4`````!005)?
M4%)/1TY!344`````.@```"5S)7,E<P``+P```%!%4DPU3$E"`````%!%4DQ,
M24(`4$523#5/4%0`````4$523$E/``!005)?24Y)5$E!3$E:140`4$%27U-0
M05=.140`4$%27T-,14%.````4$%27T1%0E5'````4$%27T-!0TA%````4$%2
M7T%21T,`````4$%27T%21U9?,```4$%27T=,3T)!3%]$14)51P````!005)?
M1TQ/0D%,7U1-4$1)4@```%!!4E]435!$25(``%!!4E]'3$]"04Q?5$5-4`!0
M05)?1TQ/0D%,7T-,14%.`````%!!4E]#3$5!3CT``#$```!365-414T``"4P
M,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I;VX@;V8@<')I
M=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*``!P87)L
M`````"YP87(`````)7,E<V-A8VAE+25S)7,``"5S)7-T96UP+25U)7,````E
M<R5S=&5M<"TE=2TE=25S`````"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E
M<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@
M;W!E<F%T:6]N*0H``$%21U8`````&````'!E<FP`````,````%5N86)L92!T
M;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`````"5S.B!E>&5C=71I;VX@;V8@
M)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@8W)E871I;VX@;V8@<')I=F%T
M92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````
M`"UE```M+0``55-%4@````!54T523D%-10````!414U01$E2`%1-4``O=&UP
M`````$Q$7TQ)0E)!4EE?4$%42`!,24)0051(`$Q)0E)!4EE?4$%42`````!$
M64Q$7TQ)0E)!4EE?4$%42````%-(3$E"7U!!5$@``&5V86P@)V5X96,@+W5S
M<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN
M:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P
M87)?=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@
M/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q
M>U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z
M.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D
M<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@
M)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E
M;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,
M24Y+(#T^(#`L"BD["G!R:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE
M(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<
M(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@
M97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B
M)PHB.PIC:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M
M<"T^9FEL96YA;64@+B`G(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M
M<#L*<WES=&5M*"1C;60I.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P
M<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE
M*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E
M9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET
M7V5N=B@I.PII9B`H97AI<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[
M4$%27T%21U9?,'T@*2!["D!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?
M(GTL("@Q("XN("1%3E9[4$%27T%21T-]("T@,2D["B0P(#T@)$5.5GM005)?
M05)'5E\P?3L*?0IE;'-E('L*9F]R("AK97ES("5%3E8I('L*9&5L971E("1%
M3E9[)%]](&EF("]>4$%27T%21U9?+SL*?0I]"FUY("1Q=6EE="`]("$D14Y6
M>U!!4E]$14)51WT["FUY("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D
M7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H
M)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I
M+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@
M.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*
M;7D@*"1S=&%R=%]P;W,L("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L
M87-T.PIB:6YM;V1E*%]&2"D["FUY("1B=68["G-E96L@7T9(+"`M."P@,CL*
M<F5A9"!?1D@L("1B=68L(#@["FQA<W0@=6YL97-S("1B=68@97$@(EQN4$%2
M+G!M7&XB.PIS965K(%]&2"P@+3$R+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*
M<V5E:R!?1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PIR96%D(%]&
M2"P@)&)U9BP@-#L*)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R
M97%U:7)E7VQI<W0["G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&
M2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I
M.PIM>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE
M("(D9G5L;&YA;64B+BXN*2D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S
M?%XH6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA
M;64L("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*
M<F5A9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB
M+"`D8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z
M<&U\<&Q\:7A\86PI)"]I*2!["FUY("@D;W5T+"`D9FEL96YA;64I(#T@7W1E
M;7!F:6QE*"1E>'0L("1C<F,I.PII9B`H)&]U="D@>PIB:6YM;V1E*"1O=70I
M.PIP<FEN="`D;W5T("1B=68["F-L;W-E("1O=70["F-H;6]D(#`W-34L("1F
M:6QE;F%M93L*?0HD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@
M/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE
M?2`]("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H
M;&EB+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE
M;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*;W5T<R@B
M4TA,24(Z("1F:6QE;F%M95QN(BD["F]P96X@;7D@)&]U="P@)SXG+"`D9FEL
M96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1O=70I.PIP<FEN="`D;W5T("1B
M=68["F-L;W-E("1O=70["GT*96QS92!["B1R97%U:7)E7VQI<W1[)&9U;&QN
M86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA;65](#T@
M>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U;&QN86UE
M+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B
M('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M
M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T92`D<F5Q
M=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R96%C:"`H
M:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M;V1U;&5<
M120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)3D-[)&UO
M9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF("@D14Y6
M>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY
M("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$["F)I;FUO
M9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E96LH)&9H
M+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@*"1O=70L("1N86UE
M*2`](%]T96UP9FEL92@G+G!M)RP@)&9I;&5N86UE+3Y[8W)C?2D["FEF("@D
M;W5T*2!["F)I;FUO9&4H)&]U="D["G!R:6YT("1O=70@)&9I;&5N86UE+3Y[
M8G5F?3L*8VQO<V4@)&]U=#L*?0IO<&5N(&UY("1F:"P@)SPG+"`D;F%M92!O
M<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*<F5T=7)N("1F:#L*?0ID:64@(D)O
M;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN(CL*
M?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V
M>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)
M3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E
M<75I<F5?;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@
M)&9I;&5N86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN
M<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I
M;&5N86UE('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L
M)"\["GT*?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FQA
M<W0@=6YL97-S("1B=68@97$@(E!+7#`P,UPP,#0B.PHD<W1A<G1?<&]S(#T@
M*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U
M;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!
M4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET
M>2!P<F]B;&5M*0HD<75I970@/2`P('5N;&5S<R`D14Y6>U!!4E]$14)51WT[
M"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM<&%R+6]P=&EO
M;G,G("8F('-H:69T*2D@>PIM>2`E9&ES=%]C;60@/2!Q=R@*<"`@(&)L:6)?
M=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU("`@=6YI;G-T86QL7W!A<@IS("`@
M<VEG;E]P87(*=B`@('9E<FEF>5]P87(**3L*:68@*$!!4D=6(&%N9"`D05)'
M5ELP72!E<2`G+2UR975S92<I('L*<VAI9G0@0$%21U8["B1%3E9[4$%27T%0
M4%]2155317T@/2!S:&EF="!`05)'5CL*?0IE;'-E('L@(R!N;W)M86P@<&%R
M;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I;F,["G=H:6QE("A`05)'5BD@>PHD
M05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q<&EU<U1V72DH+BHI+R!O<B!L87-T
M.PII9B`H)#$@97$@)TDG*2!["G!U<V@@0&%D9%]T;U]I;F,L("0R.PI]"F5L
M<VEF("@D,2!E<2`G32<I('L*979A;"`B=7-E("0R(CL*?0IE;'-I9B`H)#$@
M97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)T\G*2!["B1O=70@/2`D,CL*?0IE;'-I9B`H)#$@97$@)V(G*2!["B1B
M=6YD;&4@/2`G<VET92<["GT*96QS:68@*"0Q(&5Q("=")RD@>PHD8G5N9&QE
M(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q("=Q)RD@>PHD<75I970@/2`Q.PI]
M"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E;B`D;&]G9F@L("(^/B(L("0R(&]R
M(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L;V<Z("0A(CL*?0IE;'-I9B`H)#$@
M97$@)U0G*2!["B1C86-H95]N86UE(#T@)#(["GT*<VAI9G0H0$%21U8I.PII
M9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD,7TI('L*9&5L971E("1%3E9[)U!!
M4E]414U0)WT["FEN:71?:6YC*"D["G)E<75I<F4@4$%2.CI$:7-T.PHF>R)0
M05(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S<R!`05)'5CL*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*97AI=#L*?0I]"G5N<VAI9G0@0$E.
M0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H)&]U="D@>PI["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1P87(@/2!S:&EF
M="A`05)'5BD["FUY("1Z:7`["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M
M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@
M)"$B.PIB:6YM;V1E*"1F:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z
M:7`@/2!!<F-H:79E.CI::7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO
M<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O
M('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%
M5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^
M(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<[
M"GT*?3L*;&]C86P@)"\@/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N
M(%!!4BP@)SPG+"`D<&%R(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!
M4BD["F1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^
M(&5Q(")02UPP,#-<,#`T(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H
M(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\
M($E/.CI&:6QE.CI/7U=23TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*
M,#<W-RP**2!O<B!D:64@)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE
M9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@
M,"P@,#L*;7D@)&QO861E<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!
M4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2![
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`M/FYE=RT^87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@
M;7D@)&ME>2`H<V]R="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME
M>7T@;W(@;F5X=#L*)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B
M72\["FUY("1M86=I8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?
M(CL*;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO
M861E<B`]?B!S>R1M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X
M("AL96YG=&@H)#$I("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I
M;G0H)&QO861E<BD["B0O(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I
M<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I
M.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`]('-O
M<G0@>PIL96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"GT@9W)E<"!["B$O0E-$
M4$%.+PI](&=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z
M.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*;7D@)69I;&5S.PHO7E\\
M*"XK*20O(&%N9"`M92`D,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z
M.CL*)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@
M/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T["FUY("5W<FET=&5N.PIF;W)E
M86-H("AS;W)T(&ME>7,@)69I;&5S*2!["FUY("@D;F%M92P@)&9I;&4I.PIF
M;W)E86-H(&UY("1D:7(@*$!I;F,I('L*:68@*"1N86UE(#T@)%!!4CHZ2&5A
M=GDZ.D9U;&Q#86-H97LD7WTI('L*)&9I;&4@/2`D7SL*;&%S=#L*?0IE;'-I
M9B`H+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B@D9FEL92P@)&YA
M;64I(#T@*"0Q+"`D,BD["FQA<W0["GT*96QS:68@*&TA7B]L;V%D97(O6UXO
M72LO*"XJ6UY#8UTI7%HA*2!["FEF("AM>2`D<F5F(#T@)%!!4CHZ2&5A=GDZ
M.DUO9'5L94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D
M,2D["FQA<W0["GT*96QS:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N
M86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*;F5X="!U;FQE
M<W,@9&5F:6YE9"`D;F%M92!A;F0@;F]T("1W<FET=&5N>R1N86UE?2LK.PIN
M97AT(&EF("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT
M7$4D+SL*;W5T<R@@:F]I;B`B(BP*<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE
M(#\@)&9I;&4M/GMN86UE?2`Z("1F:6QE+`IQ<2@B+BXN*0HI.PIM>2`D8V]N
M=&5N=#L*:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U
M9GT["GT*96QS92!["F]P96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A
M;B=T(&]P96X@)&9I;&4Z("0A(CL*8FEN;6]D92A&24Q%*3L*)&-O;G1E;G0@
M/2`\1DE,13X["F-L;W-E($9)3$4["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^
M;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE*0II9B`A)$5.5GM005)?5D52
M0D%424U](&%N9"`D;F%M92`]?B`O7"XH/SIP;7QI>'QA;"DD+VD["E!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D
M9FEL92P@)&YA;64I.PI]"F]U=',H<7$H5W)I='1E;B!A<R`B)&YA;64B*2D[
M"B1F:"T^<')I;G0H(D9)3$4B*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N
M9W1H*"1N86UE*2`K(#DI*3L*)&9H+3YP<FEN="AS<')I;G1F*`HB)3`X>"\E
M<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA
M;64**2D["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI
M*3L*)&9H+3YP<FEN="@D8V]N=&5N="D["GT*?0HD>FEP+3YW<FET951O1FEL
M94AA;F1L92@D9F@I(&EF("1Z:7`["B1C86-H95]N86UE(#T@<W5B<W1R("1C
M86-H95]N86UE+"`P+"`T,#L*:68@*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT
M:6UE(#T@*'-T870H)&]U="DI6SE=*2!["FUY("1C='@@/2!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@
M;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1O
M=70L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E
M;BAM>2`D9F@L("(\)&]U="(I*2!["F)I;FUO9&4H)&9H*3L*)&-T>"T^861D
M9FEL92@D9F@I.PIC;&]S92@D9F@I.PI]"GT*)&-A8VAE7VYA;64@/2`D8W1X
M(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE.PI]"B1C86-H95]N86UE("X]
M(")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?;F%M
M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H+3YP
M<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I*2D[
M"B1F:"T^<')I;G0H(EQN4$%2+G!M7&XB*3L*)&9H+3YC;&]S93L*8VAM;V0@
M,#<U-2P@)&]U=#L*97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T
M87)T7W!O<SL*7V9I>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN
M9#L*<F5Q=6ER92!!<F-H:79E.CI::7`["GT*;7D@)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W.PHD9F@M/F9D;W!E
M;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B1Z:7`M/G)E
M861&<F]M1FEL94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ
M6FEP.CI!6E]/2R@I(&]R(&1I92`B)"$Z("1`(CL*<'5S:"!`4$%2.CI,:6)#
M86-H92P@)'II<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`[
M"B1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["F]U=',H<7$H7"1%3E9[4$%2
M7U1%35!](#T@(B1%3E9[4$%27U1%35!](BDI.PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]414U0?2D@>R`C('-H;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*
M9F]R96%C:"!M>2`D;65M8F5R("@@)'II<"T^;65M8F5R<R`I('L*;F5X="!I
M9B`D;65M8F5R+3YI<T1I<F5C=&]R>3L*;7D@)&UE;6)E<E]N86UE(#T@)&UE
M;6)E<BT^9FEL94YA;64["FYE>'0@=6YL97-S("1M96UB97)?;F%M92`]?B!M
M>PI>"B\_<VAL:6(O"B@_.B1#;VYF:6<Z.D-O;F9I9WMV97)S:6]N?2\I/PHH
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"BA;7B]=*RD*)`I]>#L*
M;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S=%]N86UE(#T@1FEL93HZ
M4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@)&5X=')A8W1?;F%M92D[
M"FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@)&UE;6)E<BT^=6YC;VUP
M<F5S<V5D4VEZ92@I*2!["F]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?;F%M
M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B*2D[
M"GT@96QS92!["F]U=',H<7$H17AT<F%C=&EN9R`B)&UE;6)E<E]N86UE(B!T
M;R`B)&1E<W1?;F%M92(I*3L*)&UE;6)E<BT^97AT<F%C=%1O1FEL94YA;65D
M*"1D97-T7VYA;64I.PIC:&UO9"@P-34U+"`D9&5S=%]N86UE*2!I9B`D7D\@
M97$@(FAP=7@B.PI]"GT*?0I]"G5N;&5S<R`H)%!!4CHZ3&EB0V%C:&5[)'!R
M;V=N86UE?2D@>PID:64@/#P@(BXB('5N;&5S<R!`05)'5CL*57-A9V4Z("0P
M(%L@+4%L:6(N<&%R(%T@6R`M261I<B!=(%L@+4UM;V1U;&4@72!;('-R8RYP
M87(@72!;('!R;V=R86TN<&P@70HD,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@
M<W)C+G!A<@HN"B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M92`]("0P
M(#T@<VAI9G0H0$%21U8I.PI]"G-U8B!#<F5A=&50871H('L*;7D@*"1N86UE
M*2`]($!?.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIM>2`H)&)A<V5N86UE
M+"`D<&%T:"P@)&5X="D@/2!&:6QE.CI"87-E;F%M93HZ9FEL97!A<G-E*"1N
M86UE+"`H)UPN+BHG*2D["G)E<75I<F4@1FEL93HZ4&%T:#L*1FEL93HZ4&%T
M:#HZ;6MP871H*"1P871H*2!U;FQE<W,H+64@)'!A=&@I.R`C(&UK<&%T:"!D
M:65S('=I=&@@97)R;W(*?0IS=6(@<F5Q=6ER95]M;V1U;&5S('L*<F5Q=6ER
M92!L:6(["G)E<75I<F4@1'EN84QO861E<CL*<F5Q=6ER92!I;G1E9V5R.PIR
M97%U:7)E('-T<FEC=#L*<F5Q=6ER92!W87)N:6YG<SL*<F5Q=6ER92!V87)S
M.PIR97%U:7)E($-A<G`["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@
M17)R;F\["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PIR97%U:7)E($5X<&]R
M=&5R.PIR97%U:7)E($9C;G1L.PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I
M<F4@1FEL93HZ4W!E8SL*<F5Q=6ER92!84TQO861E<CL*<F5Q=6ER92!#;VYF
M:6<["G)E<75I<F4@24\Z.DAA;F1L93L*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q
M=6ER92!#;VUP<F5S<SHZ6FQI8CL*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E
M<75I<F4@4$%2.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@4$%2.CI$
M:7-T.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT.PIR97%U:7)E(&%T=')I8G5T97,[
M"F5V86P@>R!R97%U:7)E($-W9"!].PIE=F%L('L@<F5Q=6ER92!7:6XS,B!]
M.PIE=F%L('L@<F5Q=6ER92!38V%L87(Z.E5T:6P@?3L*979A;"![(')E<75I
M<F4@07)C:&EV93HZ56YZ:7`Z.D)U<G-T('T["F5V86P@>R!R97%U:7)E(%1I
M93HZ2&%S:#HZ3F%M961#87!T=7)E('T["F5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"G-U8B!?<V5T7W!A<E]T
M96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%2
M7U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]
M"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-
M4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0
M("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M
M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED
M.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^
M.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R
M;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P
M=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M
M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<[
M"GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T
M:"1#;VYF:6=[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I
M.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@
M86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@
M*&UY("1F:"P@(CPB+B`D<')O9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS
M>7-R96%D("1F:"P@;7D@)&)U9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B
M*2!["G-E96L@)&9H+"`M-3@L(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*
M)&)U9B`]?B!S+UPP+R]G.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]
M8V%C:&4M(B`N("1B=68["GT*96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V
M86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@
M?0I\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M
M/FYE=R!].PIM>2`D<VAA7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!
M.CI615)324].('T@?'P@,#L*:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@
M;W(@)'-H85]V97)S:6]N(&5Q("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P
M<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N
M9"!O<&5N*&UY("1F:"P@(CPD<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D[
M"B1C='@M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER
M("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^
M:&5X9&EG97-T(#H@)&UT:6UE("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*
M)$5.5GM005)?0TQ%04Y](#T@,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E
M;&EM?71E;7`M)"0B.PI]"B1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK
M9&ER("1S=&UP9&ER+"`P-S4U.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF
M("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\[
M"GT*<W5B(%]T96UP9FEL92!["FUY("@D97AT+"`D8W)C*2`]($!?.PIM>2`H
M)&9H+"`D9FEL96YA;64I.PHD9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D
M97AT(CL*:68@*"1%3E9[4$%27T-,14%.?2D@>PIU;FQI;FL@)&9I;&5N86UE
M(&EF("UE("1F:6QE;F%M93L*<'5S:"!`=&UP9FEL92P@)&9I;&5N86UE.PI]
M"F5L<V4@>PIR971U<FX@*'5N9&5F+"`D9FEL96YA;64I(&EF("@M<B`D9FEL
M96YA;64I.PI]"F]P96X@)&9H+"`G/B<L("1F:6QE;F%M92!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0IS=6(@
M7W-E=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%
M?2!A;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA
M;64@/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-
M4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I
M('L*)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G
M;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?
M4%)/1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]
M*2`^/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*
M<F5T=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[
M7V5X97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX[
M"GT*?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S
M97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%2
M7U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O
M7%$D0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*
M:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E
M>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G
M;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE
M('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L
M("1#;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I
M9WM?9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W
M9#HZ9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R
M.CI'971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D
M<'=D*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI
M;7U<12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%
M?2`]("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.
M5GM005)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@
M>PHD14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.
M140@5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12!!4D=#($%21U9?
M,"`I("D@>PID96QE=&4@)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-
M4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@
M)$5.5GLG4$%27T=,3T)!3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,
M3T)!3%\G+B1??3L*?0IM>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!
M3E]?("`@("`@("`@("`@("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E
M;&5T92`D14Y6>U!!4E]#3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM0
M05)?1TQ/0D%,7T-,14%.?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C
M;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@
M/2`D,2!I9B`D=F%L=64@/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B
M(&]U=',@>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT
M("1L;V=F:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U
M8B!I;FET7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@
M9&5F:6YE9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB
M97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A
M<F-H97AP('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER
M92!005(["G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM
M<&]R="A`<&%R7V%R9W,I.PID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E
M<FP@<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T
M;W)Y7&XI"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]2
M13HZ97AI="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("1`(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]2
M13HZ97AI="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.
M1%]?"@#(4/]_`0``````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````%!P!`.@;`0``
M`````0````$````!````!0(```$````0`@```0```!H"```!````:0(```$`
M``"\`P```0```-P#```,````:!4!``T````\B@$`&0```-S.`@`;````!```
M`!H```#@S@(`'`````0```#U_O]OK`$!``4```!L#`$`!@```&P%`0`*````
M7`4```L````0````%0`````````#`````-`"``(````H`@``%````!$````7
M````0!,!`!$````($P$`$@```#@````3````"````/[__V^H$@$`____;P,`
M``#P__]OR!$!````````````````````````````````````````````````
M`````````````````.C.`@```````````'@5`0!X%0$`>!4!`'@5`0!X%0$`
M>!4!`'@5`0!X%0$`>!4!`'@5`0!X%0$`>!4!`'@5`0!X%0$`>!4!`'@5`0!X
M%0$`>!4!`'@5`0!X%0$`>!4!`'@5`0!X%0$`>!4!`'@5`0!X%0$`>!4!`'@5
M`0!X%0$`>!4!`'@5`0!X%0$`>!4!`'@5`0!X%0$`>!4!`'@5`0!X%0$`>!4!
M`'@5`0!X%0$`>!4!`'@5`0!X%0$`>!4!`'@5`0!X%0$`>!4!`'@5`0!X%0$`
M>!4!`'@5`0!X%0$`>!4!`'@5`0!X%0$`>!4!`'@5`0!X%0$`>!4!`'@5`0!X
M%0$`>!4!`'@5`0!X%0$`>!4!`'@5`0!X%0$`>!4!`````````````````/__
M__]4C@$`1T-#.B`H1&5B:6%N(#0N.2XR+3$P*2`T+CDN,@!'0T,Z("A$96)I
M86X@-"XX+C,M,3,I(#0N."XS`$$I````865A8FD``1\````%-%0`!@((`0D!
M$@03`10!%0$7`Q@!&0$:`@`N<VAS=')T86(`+FEN=&5R<``N;F]T92Y!0DDM
M=&%G`"YN;W1E+F=N=2YB=6EL9"UI9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN
M<W1R`"YG;G4N=F5R<VEO;@`N9VYU+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L
M+G!L=``N:6YI=``N=&5X=``N9FEN:0`N<F]D871A`"Y!4DTN97AI9'@`+F5H
M7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`
M+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T<FEB=71E<P````$`
M``!X%0$`````````#``$````B!4!``````````P``0```(P5`0`````````,
M```D80`D9```````````````````````````````````````````````````
M``````L````!`````@```%0!`0!4`0``$P```````````````0`````````3
M````!P````(```!H`0$`:`$``"````````````````0`````````(0````<`
M```"````B`$!`(@!```D```````````````$`````````#0```#V__]O`@``
M`*P!`0"L`0``P`,```4`````````!`````0````^````"P````(```!L!0$`
M;`4````'```&`````0````0````0````1@````,````"````;`P!`&P,``!<
M!0`````````````!`````````$X```#___]O`@```,@1`0#($0``X`````4`
M`````````@````(```!;````_O__;P(```"H$@$`J!(``&`````&`````P``
M``0`````````:@````D````"````"!,!``@3```X````!0`````````$````
M"````',````)````0@```$`3`0!`$P``*`(```4````,````!`````@```!\
M`````0````8```!H%0$`:!4``!````````````````0`````````=P````$`
M```&````>!4!`'@5``!0`P`````````````$````!````((````!````!@``
M`,@8`0#(&```='$`````````````!`````````"(`````0````8````\B@$`
M/(H```P```````````````0`````````C@````$````"````2(H!`$B*```0
M0``````````````$`````````)8````!``!P@@```%C*`0!8R@``"`````T`
M````````!`````````"A`````0````(```!@R@$`8,H```0`````````````
M``0`````````JP````X````#````W,X"`-S.```$```````````````$````
M`````+<````/`````P```.#.`@#@S@``!```````````````!`````````##
M`````0````,```#DS@(`Y,X```0```````````````0`````````R`````8`
M```#````Z,X"`.C.```8`0``!@`````````$````"````-$````!`````P``
M``#0`@``T```)`$`````````````!`````0```#6`````0````,````DT0(`
M)-$``!````````````````0`````````W`````@````#````.-$"`#31``!$
M$``````````````(`````````.$````!````,``````````TT0``.@``````
M`````````0````$```#J`````P``<```````````;M$``"H`````````````
M``$``````````0````,``````````````)C1``#Z```````````````!````
$````````
